[all-commits] [llvm/llvm-project] 8b96dd: [SLP]Do not reuse transformed nodes in gathers emi...

Alexey Bataev via All-commits all-commits at lists.llvm.org
Mon Sep 28 06:00:49 PDT 2026


  Branch: refs/heads/users/alexey-bataev/spr/slpfix-fmulfadd-fusion-costs-and-retry-fma-seeds-after-all-blocks
  Home:   https://github.com/llvm/llvm-project
  Commit: 8b96ddbf9cb3437ee4e47a9f60dc983a1f2be8d5
      https://github.com/llvm/llvm-project/commit/8b96ddbf9cb3437ee4e47a9f60dc983a1f2be8d5
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/SLPVectorizer.cpp
    A llvm/test/Transforms/SLPVectorizer/X86/trimmed-node-matching-gather-emitted-first.ll

  Log Message:
  -----------
  [SLP]Do not reuse transformed nodes in gathers emitted before their user

Gathers of the users with all scalars used outside the block are emitted
before the user, while the transformed nodes are emitted with the user.
Reusing such a transformed node postponed the gather and moved only the
last instruction of the transformed node buildvector, breaking dominance.

Fixes #226674

Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/226687


  Commit: ea0493b90c036776652105da246ce3fa56e33901
      https://github.com/llvm/llvm-project/commit/ea0493b90c036776652105da246ce3fa56e33901
  Author: Balázs Benics <benicsbalazs at gmail.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    A clang/include/clang/ScalableStaticAnalysis/Analyses/VirtualMethodFamily/VirtualMethodFamily.h
    M clang/include/clang/ScalableStaticAnalysis/BuiltinAnchorSources.def
    M clang/lib/ScalableStaticAnalysis/Analyses/CMakeLists.txt
    A clang/lib/ScalableStaticAnalysis/Analyses/VirtualMethodFamily/VirtualMethodEntityExtractor.cpp
    A clang/unittests/ScalableStaticAnalysis/Analyses/VirtualMethodFamily/VirtualMethodFamilyExtractorTest.cpp
    A clang/unittests/ScalableStaticAnalysis/Analyses/VirtualMethodFamily/VirtualMethodFamilyTestSupport.h
    M clang/unittests/ScalableStaticAnalysis/CMakeLists.txt
    A clang/unittests/ScalableStaticAnalysis/ParsedAST.h

  Log Message:
  -----------
  [SSAF] Extract the virtual method override relation per TU (#213316)

A virtual call may dispatch to any override of its callee, so a whole-program
analysis cannot reason about a method's parameters and return value in
isolation. It needs to know which method overrides which, and which slots
that relates. Collect this per TU, so a later pass can join the related
slots into families.

JSON serialization lands separately, so the summary is not writable via
`--ssaf-extract-summaries` yet.

§1 of rdar://179151603

Assisted-By: claude


  Commit: 2305da864cb3b66e1fe857c3018bf7d94253bb8a
      https://github.com/llvm/llvm-project/commit/2305da864cb3b66e1fe857c3018bf7d94253bb8a
  Author: Dmitry Sidorov <Dmitry.Sidorov at amd.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    A llvm/test/Transforms/SLPVectorizer/AMDGPU/cross-block-fmul-fadd.ll

  Log Message:
  -----------
  [NFC][SLP][AMDGPU] Precommit a cross-block fmul fadd contraction test (#226609)

Two contract fmuls feed contract fadds in different successors. AMDGPU
sinks such an fmul into the block of its user and fuses the pair, so the
scalar form is one fma per path. Record the current behaviour, the pair
is kept scalar when the fmul is operand 0 of the fadd and paired when it
is operand 1.


  Commit: 6b85e67a473ebe127aa31b742adc1fe2d53cb5bf
      https://github.com/llvm/llvm-project/commit/6b85e67a473ebe127aa31b742adc1fe2d53cb5bf
  Author: Konstantinos Parasyris <koparasy at gmail.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M clang/include/clang/CIR/Dialect/IR/CIRCUDAAttrs.td
    M clang/include/clang/CIR/Dialect/IR/CIRDialect.td
    M clang/lib/CIR/CodeGen/CIRGenCUDANV.cpp
    M clang/lib/CIR/CodeGen/CIRGenModule.cpp
    M clang/lib/CIR/Dialect/IR/CIRDialect.cpp
    M clang/lib/CIR/Dialect/Transforms/LoweringPrepare.cpp
    M clang/test/CIR/CodeGenCUDA/device-stub.cu
    A clang/test/CIR/CodeGenCUDA/missing-gpubinary.cu
    A clang/test/CIR/Diagnostics/mlir-error-routing.cpp
    R clang/test/CIR/Diagnostics/mlir-error-routing.cu
    A clang/test/CIR/IR/invalid-cuda-device-binary.cir

  Log Message:
  -----------
  [CIR][CUDA] Read fat binary in CIRGen and store its bytes on the module (#225971)

Two problems with the current implementation of GPU CIR:

1. `LoweringPrepare` read the fat binary from disk, via
`astCtx->getSourceManager().getFileManager().getVirtualFileSystem()`. A
   transform pass should not do I/O, and this is one of the `ASTContext`
   dependencies that keeps the post-CIRGen pipeline from being IR-to-IR.
Some of the related discussion on this has been done
[here](https://discourse.llvm.org/t/rfc-clangir-making-cir-pipeline-boundaries-first-class-driver-artifacts/90998)
and PR: #219048
2. `#cir.cu.binary_handle` stored the *file path*. That's a build input,
not a
property of the program: it bakes one machine's directory layout into a
   `.cir`.

The PR removes the file path and adds an attribute
CIRGen now reads the file in and records the contents 
as `#cir.cu.device_binary`, a `StringAttr` of raw bytes. The
attribute is deleted once LoweringPrepare "consumes" it. 

A couple of notes:
1. The GPU dialect has a similar representation. We may want to move
towards that direction slowly, but I don't see any value doing this now.
It will confuse the direction of this PR. 
2. The test `clang/test/CIR/Diagnostics/mlir-error-routing.cu` has
completely
changed, because it relied on an error occurring when the file attribute
was missing.
Since we deleted that attribute completely, the test was failing.

---------

Co-authored-by: Claude Opus 5 <noreply at anthropic.com>


  Commit: 0a90c92d5285cae7f7b7ae26573e39df5898cafc
      https://github.com/llvm/llvm-project/commit/0a90c92d5285cae7f7b7ae26573e39df5898cafc
  Author: Mehdi Amini <joker.eph at gmail.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M mlir/examples/toy/Ch4/include/toy/Ops.td
    M mlir/examples/toy/Ch5/include/toy/Ops.td
    M mlir/examples/toy/Ch6/include/toy/Ops.td
    M mlir/examples/toy/Ch7/include/toy/Ops.td
    M mlir/test/Analysis/DataFlow/test-last-modified-callgraph.mlir
    M mlir/test/Analysis/DataFlow/test-last-modified.mlir
    M mlir/test/Analysis/DataFlow/test-next-access.mlir
    M mlir/test/Analysis/DataFlow/test-strided-metadata-range-analysis.mlir
    M mlir/test/Dialect/Affine/affine-loop-normalize.mlir
    M mlir/test/Dialect/Affine/int-range-interface.mlir
    M mlir/test/Dialect/Affine/simplify-min-max-ops.mlir
    M mlir/test/Dialect/Affine/simplify-with-bounds.mlir
    M mlir/test/Dialect/Affine/transform-op-simplify-min-max-ops.mlir
    M mlir/test/Dialect/Arith/int-range-analysis-convergence.mlir
    M mlir/test/Dialect/Arith/int-range-interface.mlir
    M mlir/test/Dialect/Arith/int-range-loop-iter-args.mlir
    M mlir/test/Dialect/Arith/int-range-narrowing.mlir
    M mlir/test/Dialect/Arith/int-range-opts-bug-119045.mlir
    M mlir/test/Dialect/Arith/int-range-opts.mlir
    M mlir/test/Dialect/GPU/int-range-interface-cluster.mlir
    M mlir/test/Dialect/GPU/int-range-interface.mlir
    M mlir/test/Dialect/MLProgram/pipeline-globals.mlir
    M mlir/test/Dialect/MemRef/int-range-inference.mlir
    M mlir/test/Dialect/OpenACC/acc-implicit-routine.mlir
    M mlir/test/Dialect/Tensor/int-range-inference.mlir
    M mlir/test/Dialect/Vector/int-range-interface.mlir
    M mlir/test/IR/attribute.mlir
    M mlir/test/Interfaces/InferIntRangeInterface/infer-int-range-test-ops-invalid.mlir
    M mlir/test/Interfaces/InferIntRangeInterface/infer-int-range-test-ops.mlir
    M mlir/test/Transforms/loop-invariant-code-motion.mlir
    M mlir/test/Transforms/make-composed-folded-affine-apply.mlir
    M mlir/test/lib/Dialect/Test/TestDialect.td
    M mlir/test/lib/Dialect/Test/TestOps.td
    M mlir/test/lib/Dialect/Test/TestOpsSyntax.td
    M mlir/test/mlir-tblgen/constant-str-attr-invalid.mlir
    M mlir/test/mlir-tblgen/op-format-invalid.td
    M mlir/test/mlir-tblgen/op-format.mlir
    M mlir/test/mlir-tblgen/op-format.td
    M mlir/test/mlir-tblgen/pattern.mlir
    M mlir/test/python/dialects/python_test.py
    M mlir/test/python/python_test_ops.td

  Log Message:
  -----------
  [mlir] Remove remaining strict property assembly opt-outs (#226702)

Migrate Toy, test, and Python dialect formats to use prop-dict for
inherent properties. Update assembly fixtures and expected output for
strict property printing.

Assisted-by: Codex


  Commit: 688a1498b3ce9011ee58c214086e3cd408e86f5e
      https://github.com/llvm/llvm-project/commit/688a1498b3ce9011ee58c214086e3cd408e86f5e
  Author: Amit Tiwari <Amit.Tiwari at amd.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M clang/lib/Sema/SemaOpenMP.cpp
    A clang/test/OpenMP/collapse_iv_width_codegen.cpp

  Log Message:
  -----------
  [Clang][OpenMP] Optimize `collapse` IV bit-width precision expression (#225612)

`collapse` used to build both a 32-bit and a 64-bit trip-count, then
keep one.

This patch does the same in `checkOpenMPLoop`:

If we know 32-bit is enough, build only 32-bit.
Else build 64-bit first.
Build 32-bit only when the product is a compile-time constant and fits.

Origin: `flatten` already builds only the width it keeps.


  Commit: e217205575ac65acd6d301b036bea8875f5eaa16
      https://github.com/llvm/llvm-project/commit/e217205575ac65acd6d301b036bea8875f5eaa16
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/VPlanRecipes.cpp
    M llvm/test/Transforms/LoopVectorize/AArch64/conditional-scalar-assignment-fold-tail.ll
    M llvm/test/Transforms/LoopVectorize/AArch64/conditional-scalar-assignment.ll
    M llvm/test/Transforms/LoopVectorize/RISCV/conditional-scalar-assignment-fold-tail.ll
    M llvm/test/Transforms/LoopVectorize/RISCV/conditional-scalar-assignment.ll
    M llvm/test/Transforms/LoopVectorize/X86/conditional-scalar-assignment.ll
    M llvm/test/Transforms/LoopVectorize/find-last-ptr-induction.ll
    M llvm/test/Transforms/LoopVectorize/iv-select-cmp-non-const-iv-start.ll
    M llvm/test/Transforms/LoopVectorize/iv-select-cmp-trunc.ll
    M llvm/test/Transforms/LoopVectorize/iv-select-cmp.ll

  Log Message:
  -----------
  [VPlan] Mark default value or ExtractLastActive as only first lane used. (#226153)

The default value (operand 0) of ExtractLastActive is the scalar value
of @llvm.experimental.vector.extract.last.active. Only the first lane is
used, mark accordingly.

PR: https://github.com/llvm/llvm-project/pull/226153


  Commit: f950b04465ee6a198f3fa5644e4f70711041df8a
      https://github.com/llvm/llvm-project/commit/f950b04465ee6a198f3fa5644e4f70711041df8a
  Author: Kazu Hirata <kazu at google.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/include/llvm/Transforms/Utils/LoopUtils.h
    M llvm/lib/Transforms/Utils/LoopUnroll.cpp
    M llvm/lib/Transforms/Utils/LoopUtils.cpp

  Log Message:
  -----------
  [Transforms] Remove unused functions (NFC) (#226655)

createAnyOfReduction:
The last caller was removed on January 18, 2026 in commit
ae1bd068db293c494c4c6314da3b9d138706460d.

canHaveUnrollRemainder:
The last caller, in an assert, was removed on May 1, 2026 in commit
316f0d3bfeaf7eee7b6d4ae60d357a8216ec5264.

Assisted-by: Antigravity


  Commit: ab52e9f971d626346d70190df72636b477f6c089
      https://github.com/llvm/llvm-project/commit/ab52e9f971d626346d70190df72636b477f6c089
  Author: Yordan Vásquez <vyordangiovani at gmail.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M libcxx/include/complex
    M libcxx/include/valarray
    A libcxx/test/std/numerics/complex.number/complex/complex_requires_cv_unqualified_object.verify.cpp
    A libcxx/test/std/numerics/numarray/template.valarray/valarray_requires_cv_unqualified_object.verify.cpp

  Log Message:
  -----------
  [libc++] Add static_assert diagnostics for LWG3133 named requirements (#212360)

Add a static_assert to both std::complex<T> and std::valarray<T>
requiring that T be a cv-unqualified object type that satisfies the
Cpp17DefaultConstructible, Cpp17CopyConstructible, Cpp17CopyAssignable,
and Cpp17Destructible named requirements, per the revised wording in
[numeric.requirements]. This mirrors the existing pattern already used
by std::optional<T>.

Non-_v (class-style) trait forms are used throughout so that the
assertion is well-formed even when <complex>/<valarray> are included in
C++03/11/14 mode.

Test coverage:
- A .verify.cpp for complex<T> and one for valarray<T>, each covering
six failure modes: cv-qualified types, and one type violating each of
the four named requirements individually.

Follows-up e062a29cf865bb7cadea6cb605c9f3515e5b883f.


  Commit: 5302d361339066363854a4e12e16e413af9ce1ce
      https://github.com/llvm/llvm-project/commit/5302d361339066363854a4e12e16e413af9ce1ce
  Author: geoffreygaren <ggaren at apple.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M clang/docs/analyzer/checkers.md
    M clang/lib/StaticAnalyzer/Checkers/WebKit/ASTUtils.cpp
    M clang/lib/StaticAnalyzer/Checkers/WebKit/PtrTypesSemantics.cpp
    M clang/lib/StaticAnalyzer/Checkers/WebKit/PtrTypesSemantics.h
    M clang/test/Analysis/Checkers/WebKit/mock-canborrow.h
    M clang/test/Analysis/Checkers/WebKit/unborrowed-call-args.cpp
    M clang/test/Analysis/Checkers/WebKit/unborrowed-local-vars-cxx23.cpp
    M clang/test/Analysis/Checkers/WebKit/unborrowed-local-vars.cpp

  Log Message:
  -----------
  [WebKit Checkers] Add built-in recognition for standard view types (#226350)

libc++ doesn't fully annotate `[[clang::lifetimebound]]` for all view
types. This results in false negatives in borrow checking.

Ultimately we need to fix this in libc++, but for now we can work around
the most common / most important false negatives. For example, borrow
checking can now check

    for (auto& x : vector | std::views::reverse) { ... }

Assisted-by: Claude


  Commit: 207f7f00ced9adf54e79f2bbf2c59a485a608495
      https://github.com/llvm/llvm-project/commit/207f7f00ced9adf54e79f2bbf2c59a485a608495
  Author: Simon Pilgrim <llvm-dev at redking.me.uk>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/test/Analysis/CostModel/X86/arith-fp.ll

  Log Message:
  -----------
  [CostModel][X86] arith-fp.ll - test AVX512DQ instead of AVX512BW (#226519)

AVX512DQ has instructions relevant to fp arithmetic (vXi64 fp2int in particular)


  Commit: d297af3b3d7a086d64f1477cfa682a16fcfa3260
      https://github.com/llvm/llvm-project/commit/d297af3b3d7a086d64f1477cfa682a16fcfa3260
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    A llvm/test/Transforms/LoopVectorize/AArch64/sve-induction-wrapflags.ll
    M llvm/test/Transforms/LoopVectorize/induction-wrapflags.ll

  Log Message:
  -----------
  [LV] Add tests for wide induction wrap flags (NFC). (#226715)

Add tests for:
* inductions where the lane offsets may signed-overflow, even if the
scalar induction values do not,
* inductions whose increment does not directly update the phi, where the
increment's wrap flags do not apply to the induction,
* narrow inductions where the VF may exceed the signed maximum of the
induction type.


  Commit: 555d8a58b85f0cfcbad0fc7cf7b13bbef4d4ca30
      https://github.com/llvm/llvm-project/commit/555d8a58b85f0cfcbad0fc7cf7b13bbef4d4ca30
  Author: David Green <david.green at arm.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/lib/Target/AArch64/AArch64ISelLowering.cpp
    M llvm/lib/Target/AArch64/AArch64PerfectShuffle.h

  Log Message:
  -----------
  [AArch64] Reorganise perfect shuffle generation. NFC (#224526)

This adds a generatePerfectShuffle implementation for parsing through
the perfect shuffle tables, generating a list of ShuffleEntry's that
represent the sequence of shuffles that need to be performed. This is
intended to be a NFC as-is, allowing it to be reused in global isel and
extended in the future to handle shuffles that are not part of the
shuffle table. The number of instructions generated can also be used for
costing shuffles, as we do for immediate generation.


  Commit: 0ead65c731fa09596fbcc9b5109e504e9e7adb7e
      https://github.com/llvm/llvm-project/commit/0ead65c731fa09596fbcc9b5109e504e9e7adb7e
  Author: Michael G. Kazakov <mike.kazakov at gmail.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    A libcxx/test/benchmarks/algorithms/nonmodifying/pstl.find.bench.cpp
    A libcxx/test/benchmarks/algorithms/sorting/pstl.sort.bench.cpp
    A libcxx/test/benchmarks/numeric/pstl.transform_reduce.bench.cpp

  Log Message:
  -----------
  [libc++][pstl] Add more benchmarks of the parallel algorithms (#225908)

This PR adds benchmarks of these 3 parallel algorithms:
- `std::find(policy, ...)`
- `std::sort(policy, ...)`
- `std::transform_reduce(policy, ...)`

---------

Co-authored-by: Louis Dionne <ldionne.2 at gmail.com>


  Commit: 6aefa9a60eb523ca3d8601ab69509e057730ac8d
      https://github.com/llvm/llvm-project/commit/6aefa9a60eb523ca3d8601ab69509e057730ac8d
  Author: Matt Arsenault <Matthew.Arsenault at amd.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/lib/Target/ARM/ARMTargetMachine.cpp
    M llvm/lib/Target/ARM/ARMTargetMachine.h
    M llvm/lib/Target/ARM/ARMTargetObjectFile.cpp
    M llvm/lib/Target/ARM/ARMTargetObjectFile.h
    M llvm/test/CodeGen/ARM/module-target-abi.ll

  Log Message:
  -----------
  ARM: Remove cached TargetABI from ARMBaseTargetMachine (#226482)

This cannot account for the "target-abi" module flag, so
let the uses query that. ARMElfTargetObjectFile was the one user of
this value, so this failed to respect the module flag.

Co-Authored-By: Claude Opus 5 <noreply at anthropic.com>


  Commit: fc99ddb168769dd732f40b74c09f9d800c30e7e3
      https://github.com/llvm/llvm-project/commit/fc99ddb168769dd732f40b74c09f9d800c30e7e3
  Author: Alan Zhao <ayzhao at google.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/cmake/modules/GetLibraryName.cmake

  Log Message:
  -----------
  [cmake][Windows] Do not strip library prefixes on Windows (#226635)


  Commit: 808c726db2fe24f7ba2901f5701ae19cfe602f0a
      https://github.com/llvm/llvm-project/commit/808c726db2fe24f7ba2901f5701ae19cfe602f0a
  Author: Prajit Rahul <prajitrahul05 at gmail.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/docs/Lexicon.md

  Log Message:
  -----------
  [LLVM][Docs] Define IR in the lexicon (#221388)

Define IR in the LLVM lexicon using terminology from the LLVM Language
Reference Manual, including its SSA-based structure and three equivalent
representations.

Fixes #139867

AI Usage: ChatGPT


  Commit: 315a38a1ef3825e4e7ebe188353b4c5329751453
      https://github.com/llvm/llvm-project/commit/315a38a1ef3825e4e7ebe188353b4c5329751453
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/VPlanConstruction.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUtils.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUtils.h
    M llvm/test/Transforms/LoopVectorize/AArch64/epilog-vectorization-widen-inductions.ll
    M llvm/test/Transforms/LoopVectorize/X86/pr36524.ll
    M llvm/test/Transforms/LoopVectorize/induction-wrapflags.ll
    M llvm/test/Transforms/LoopVectorize/induction.ll
    M llvm/test/Transforms/LoopVectorize/pr30654-phiscev-sext-trunc.ll
    M llvm/test/Transforms/LoopVectorize/pr35773.ll
    M llvm/test/Transforms/LoopVectorize/predicated-inductions.ll
    M llvm/test/Transforms/LoopVectorize/single-value-blend-phis.ll

  Log Message:
  -----------
  [VPlan] Take wide induction wrap flags from the increment of the phi. (#226726)

The binary operator of an integer InductionDescriptor is the incoming
value from the latch, which is not required to have the phi as operand.
E.g. for

  %x = add i32 %iv, 5
  %iv.next = add nuw nsw i32 %x, 1

the flags only apply to %x + 1, while the induction step is 6, and %iv +
6 may wrap even though %iv.next does not. Determine the wrap flags from
the increment of the header phi instead, and only if it adds to or
subtracts from the phi directly.


  Commit: 899d817c7950c997402cd229935cd822acf45b08
      https://github.com/llvm/llvm-project/commit/899d817c7950c997402cd229935cd822acf45b08
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/LoopVectorize.cpp
    M llvm/test/Transforms/LoopVectorize/AArch64/sve-low-trip-count.ll
    M llvm/test/Transforms/LoopVectorize/RISCV/countable-early-exit-no-epilogue.ll

  Log Message:
  -----------
  [LV] Skip low-trip count logic there is no scalar tail. (#225633)

https://github.com/llvm/llvm-project/pull/195823 added logic consider
vectorization of low trip count loops if there was no or a single
iteration remaining.

This causes loops to be vectorized with a VF where no scalar tail
remains, even if it is required for legality (loop with multiple
countable exits require scalar epilogue to pick the exit).

For now, limit to cases where there's a scalar iteration remaining.

PR: https://github.com/llvm/llvm-project/pull/225633


  Commit: e0b3e4c82911376fcb2dfcbc4a3dd3f4f5891aba
      https://github.com/llvm/llvm-project/commit/e0b3e4c82911376fcb2dfcbc4a3dd3f4f5891aba
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/include/llvm/Analysis/LoopAccessAnalysis.h
    M llvm/lib/Analysis/LoopAccessAnalysis.cpp

  Log Message:
  -----------
  [LAA] Remove unused functions (NFC) (#226733)

Remove RuntimePointerChecking::empty and LoopAccessInfo::getNumLoads /
getNumStores, which have no callers, together with the NumLoads and
NumStores counters that were only read by the latter.


  Commit: 8c153f78f7c0a842edfee3f1601dee1776c941d6
      https://github.com/llvm/llvm-project/commit/8c153f78f7c0a842edfee3f1601dee1776c941d6
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/include/llvm/Analysis/ScalarEvolutionExpressions.h

  Log Message:
  -----------
  [SCEV] Remove unused classof(const SCEVUse *) overloads (NFC) (#226734)

isa/cast/dyn_cast on SCEVUse go through simplify_type or CastInfo.
classof(SCEVUse) is unused.


  Commit: 7615da10b75c57286a4032eac8bb43c1b8d2ba46
      https://github.com/llvm/llvm-project/commit/7615da10b75c57286a4032eac8bb43c1b8d2ba46
  Author: Dan Salvato <dan at teamsalvato.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/lib/Target/M68k/M68kExpandPseudo.cpp
    M llvm/lib/Target/M68k/M68kInstrArithmetic.td
    M llvm/lib/Target/M68k/M68kInstrData.td
    M llvm/lib/Target/M68k/M68kInstrInfo.cpp
    M llvm/lib/Target/M68k/M68kInstrInfo.h
    M llvm/test/CodeGen/M68k/Arith/divide-by-constant.ll
    M llvm/test/CodeGen/M68k/Arith/smul-with-overflow.ll
    M llvm/test/CodeGen/M68k/Arith/umul-with-overflow.ll
    M llvm/test/CodeGen/M68k/Bits/btst.ll
    M llvm/test/CodeGen/M68k/Control/cmp.ll
    M llvm/test/CodeGen/M68k/Control/non-cmov-switch.ll
    M llvm/test/CodeGen/M68k/Control/setcc.ll
    M llvm/test/CodeGen/M68k/Data/load-extend.ll
    M llvm/test/CodeGen/M68k/Data/sext-i1.ll
    M llvm/test/CodeGen/M68k/register-spills.ll

  Log Message:
  -----------
  [M68k] Finish implementation of `MOVX` (move and extend) pseudo-instructions and fix related errors (#218938)

This patch adds remaining addressing modes to the "move and extend"
pseudo-instructions, and fixes a few errors and inconsistencies in the
logic that caused inefficient code generation.

- Remaining addressing modes were implemented to match non-pseudo `MOVE`
instructions.
- Names of the pseudos now correctly reflect the register classes they
operate on, e.g. `MOVZXd32r16` for XR16 -> DR32.
- Fixed an issue where `MOVZX` could be allocated to an address
register, which has no way to zero-extend the result. (There were even
some of these in the test `register-spills.ll`, emitted as illegal
instructions, but the test doesn't have instruction verification
enabled, so it wasn't caught.)
- Fixed some `extload` patterns where the register was unnecessarily
extended to 32 bits before being truncated to its final size, causing
redundant instructions to be omitted.
- Fixed `anyext` patterns lowering to `MOVZX` instead of `MOVX`, causing
unnecessary zero-extensions.
- An inconsistency was fixed where the expansion logic would perform a
source-sized move when loading from memory, but a destination-sized move
when moving between registers. They now always perform a source-sized
move, which improves clarity in the assembly output and has more
opportunity for future optimizations.


  Commit: bf529329b5ce85d42a5c793951ec9b31100cd84e
      https://github.com/llvm/llvm-project/commit/bf529329b5ce85d42a5c793951ec9b31100cd84e
  Author: Alexander Richardson <alexrichardson at google.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    A clang/test/CodeGen/RISCV/lto-module-asm-abi.c
    A cross-project-tests/.clang-format
    A cross-project-tests/riscv/lit.local.cfg
    A cross-project-tests/riscv/lto-inline-asm-abi.c
    M lld/test/ELF/lto/riscv-target-abi.ll
    M llvm/test/CodeGen/RISCV/module-asm-features.ll
    M llvm/test/CodeGen/RISCV/riscv-func-target-feature.ll
    M llvm/test/LTO/RISCV/module-asm.ll
    M llvm/test/MC/RISCV/mapping-across-sections.s

  Log Message:
  -----------
  [RISC-V][LTO] Add baseline tests for LTO inline assembly and mapping symbols (#225129)

No functional change intended here, just adding test coverage for RISC-V LTO
inline assembly ABI handling (following up on
https://github.com/llvm/llvm-project/pull/223606) and for the `$x<arch>` ELF
mapping symbols emitted for module and function target features.

The `TODO`s for `.lto_discard` dropping module inline asm target features and
for the missing/duplicate `$x<arch>` mapping symbols will be addressed in the
following commits.

This commit was created with the help of AI tools

Pull-Request: https://github.com/llvm/llvm-project/pull/225129


  Commit: 22d3cccd0beaf7d2c7728d0bc6fa347283b0bc13
      https://github.com/llvm/llvm-project/commit/22d3cccd0beaf7d2c7728d0bc6fa347283b0bc13
  Author: Alexander Richardson <alexrichardson at google.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M cross-project-tests/riscv/lto-inline-asm-abi.c
    M llvm/lib/LTO/LTO.cpp
    M llvm/lib/Linker/IRMover.cpp
    M llvm/test/LTO/RISCV/module-asm.ll

  Log Message:
  -----------
  [LTO] Preserve module inline asm target properties for .lto_discard and symvers (#225130)

Previously, LTO::addRegularLTO() and IRLinker::run() called
prependModuleInlineAsm() and appendModuleInlineAsm() with a plain string when
synthesizing `.lto_discard` and imported `.symver` directives, creating a new
GlobalAsmFragment with empty TargetCPU and TargetFeatures instead of preserving
the existing module inline asm's properties. Copy the front fragment's Props so
these synthesized directives are merged into the module's inline asm with the
same target features.

This commit was created with the help of AI tools

Pull-Request: https://github.com/llvm/llvm-project/pull/225130


  Commit: 0ab3502ec56a5d8330c79849945b9fefd2668f01
      https://github.com/llvm/llvm-project/commit/0ab3502ec56a5d8330c79849945b9fefd2668f01
  Author: Alexander Richardson <alexrichardson at google.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/lib/Target/RISCV/MCTargetDesc/RISCVELFStreamer.cpp
    M llvm/test/MC/RISCV/mapping-across-sections.s

  Log Message:
  -----------
  [RISC-V][MC] Fix mapping symbol section tracking on popSection() (#225131)

Previously, RISCVELFStreamer::changeSection() saved LastEMS and LastEmittedArch
under getPreviousSection().first instead of getCurrentSection().first. When
MCStreamer::popSection() switches back to a previous section,
getPreviousSection() already points to the destination section being restored
rather than the section being exited. This clobbered the destination section's
saved mapping symbol state and caused duplicate `$x<arch>` mapping symbols to
be emitted whenever returning to `.text`.

Use getCurrentSection().first instead, matching AArch64ELFStreamer and
ARMELFStreamer.

This commit was created with the help of AI tools

Pull-Request: https://github.com/llvm/llvm-project/pull/225131


  Commit: 6eeb3b4ebdae20cd5f1e0fe5e74df3b418b654e2
      https://github.com/llvm/llvm-project/commit/6eeb3b4ebdae20cd5f1e0fe5e74df3b418b654e2
  Author: Alexander Richardson <alexrichardson at google.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M cross-project-tests/riscv/lto-inline-asm-abi.c
    M llvm/lib/Target/RISCV/MCTargetDesc/RISCVELFStreamer.cpp
    M llvm/lib/Target/RISCV/MCTargetDesc/RISCVELFStreamer.h
    M llvm/lib/Target/RISCV/MCTargetDesc/RISCVTargetStreamer.cpp
    M llvm/lib/Target/RISCV/MCTargetDesc/RISCVTargetStreamer.h

  Log Message:
  -----------
  [RISC-V][MC] Update ELF streamer ArchString in setFlagsFromFeatures() (#225140)

During LTO, the TargetMachine subtarget is initialized with the linker's
default CPU (e.g. `generic-rv64`, `rv64i2p1`), while
RISCVAsmPrinter::emitStartOfAsmFile() reconstructs the module's actual ISA from
the `riscv-isa` module flag and calls RISCVTargetStreamer::setFlagsFromFeatures()
and RISCVTargetStreamer::emitTargetAttributes(). Because
RISCVTargetELFStreamer previously only initialized InitialArchString and
ArchString in its constructor rather than in setFlagsFromFeatures(), direct
object emission bypassed the update and tagged `.text` with `$xrv64i2p1`
instead of the module's full architecture string.

Move the InitialArchString and ArchString initialization into
RISCVTargetELFStreamer::setFlagsFromFeatures() and also call setArchString()
alongside emitTextAttribute(RISCVAttrs::ARCH, ...) in
RISCVTargetStreamer::emitTargetAttributes().

This commit was created with the help of AI tools

Pull-Request: https://github.com/llvm/llvm-project/pull/225140


  Commit: 0e2ebe79f5c4ea36d7daecb76fb4867452d6973e
      https://github.com/llvm/llvm-project/commit/0e2ebe79f5c4ea36d7daecb76fb4867452d6973e
  Author: Alexander Richardson <alexrichardson at google.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/lib/Target/RISCV/RISCVAsmPrinter.cpp
    M llvm/test/CodeGen/RISCV/module-asm-features.ll
    M llvm/test/CodeGen/RISCV/riscv-func-target-feature.ll

  Log Message:
  -----------
  [RISC-V] Update streamer ArchString in emitTargetFeaturePush() (#225133)

Previously, RISCVAsmPrinter::emitTargetFeaturePush() only emitted `.option push`
and `.option arch` without updating the streamer's active ArchString. When
emitting an ELF object file directly (`-filetype=obj`),
RISCVTargetELFStreamer::emitDirectiveOptionArch() is a no-op while
emitTargetFeaturePop() resets ArchString back to the pushed ArchString, so
module-level inline assembly and functions with custom `target-features` failed
to emit updated `$x<arch>` mapping symbols.

Call RTS.setArchString() with the parsed ISA string in emitTargetFeaturePush()
so `-filetype=obj` records the active `$x<arch>` mapping symbol alongside
`.option arch`.

This commit was created with the help of AI tools

Pull-Request: https://github.com/llvm/llvm-project/pull/225133


  Commit: b380036c75b82ab16aa988331b65cea6323091e7
      https://github.com/llvm/llvm-project/commit/b380036c75b82ab16aa988331b65cea6323091e7
  Author: Aiden Grossman <aidengrossman at google.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M .github/workflows/docs.yml

  Log Message:
  -----------
  [Github] Build BOLT docs on changes (#226747)

We were already set up to build the BOLT docs, but the workflow did not
actually trigger on changes to the BOLT docs specifically. This change
fixes that.


  Commit: fb9596b7117dac3a1bc680b1041464944d0caa24
      https://github.com/llvm/llvm-project/commit/fb9596b7117dac3a1bc680b1041464944d0caa24
  Author: Letu Ren <fantasquex at gmail.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M mlir/lib/Target/LLVMIR/Dialect/LLVMIR/LLVMToLLVMIRTranslation.cpp
    M mlir/test/Target/LLVMIR/llvmir.mlir

  Log Message:
  -----------
  [MLIR][LLVM] Produce canonical const GEP in convertGEPOp (#226699)

The DataLayout overload of ConstantExpr::getGetElementPtr is the form
that replaces typed constant GEPs. Use it for inrange GEPs and fail
translation when the indices cannot be reduced to a byte offset.

This resolves
https://github.com/llvm/llvm-project/pull/220424#discussion_r4092337505

Assisted-by: grok-4.7
Signed-off-by: Letu Ren <fantasquex at gmail.com>


  Commit: e54a8d183eda0097771b422399ee929a334fb0af
      https://github.com/llvm/llvm-project/commit/e54a8d183eda0097771b422399ee929a334fb0af
  Author: Alan Zhao <ayzhao at google.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/cmake/modules/GetLibraryName.cmake

  Log Message:
  -----------
  [cmake][Windows] Fix CMake variable (#226745)

As a follow-up fix to #226635, the variable is `WIN32` not `Win32`.


  Commit: 32ee4f7ed0ba2f169d22416c73360146153c9711
      https://github.com/llvm/llvm-project/commit/32ee4f7ed0ba2f169d22416c73360146153c9711
  Author: Craig Topper <craig.topper at sifive.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M llvm/include/llvm/CodeGen/SDPatternMatch.h

  Log Message:
  -----------
  [SDPatternMatch] Simplify EffectiveOperands and drop the template specialization. NFC (#226036)

The chain and glue operands are in fixed locations, we don't need a loop
to find them.

Use the template parameter to skip the constructor body instead of using
template specialization.


  Commit: 50f802581bd16b82bd68a9a4682cdbdc560368df
      https://github.com/llvm/llvm-project/commit/50f802581bd16b82bd68a9a4682cdbdc560368df
  Author: Timm Baeder <tbaeder at redhat.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M clang/include/clang/AST/APValue.h
    M clang/lib/AST/ExprConstant.cpp

  Log Message:
  -----------
  [clang][AST] Mark APValue as LLVM_ATTRIBUTE_WARN_UNUSED (#226632)


  Commit: 4c85cbebc59d62d6845ea31f649d8519813b55ff
      https://github.com/llvm/llvm-project/commit/4c85cbebc59d62d6845ea31f649d8519813b55ff
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M clang/docs/AllocToken.md
    M clang/docs/ClangLinkerWrapper.md
    M clang/docs/ClangOffloadBundler.md
    M clang/docs/ClangTransformerTutorial.md
    M clang/docs/ControlFlowIntegrity.md
    M clang/docs/ControlFlowIntegrityDesign.md
    M clang/docs/InternalsManual.md
    M clang/docs/IntroductionToTheClangAST.md
    M clang/docs/LanguageExtensions.md
    M clang/docs/LibASTImporter.md
    M clang/docs/LifetimeSafety.md
    M clang/docs/SafeBuffers.md
    M clang/docs/ScalableStaticAnalysis/user-docs/SummaryExtraction.md
    M clang/docs/WarningSuppressionMappings.md
    M clang/docs/analyzer/checkers.md
    M clang/docs/analyzer/user-docs/Annotations.md
    M clang/docs/conf.py
    M clang/include/clang/Basic/AttrDocs.td
    M llvm/docs/SphinxQuickstartTemplate.md
    M utils/docs/llvm_sphinx/ext/absolute_links.py
    M utils/docs/llvm_sphinx/ext/absolute_links_test/markdown.md

  Log Message:
  -----------
  [docs] Replace clang.llvm.org/docs links with Sphinx links (#222507)

Use Sphinx document and option roles or project-relative links for links
within the Clang documentation. Repair stale generated-document
fragments found while validating the replacements. This ensures that
standalone documentation builds are self-contained, although
cross-project links (Clang->LLVM) typically go via absolute llvm.org
hrefs.

Part of #214861

Assisted-by: Codex


  Commit: dbea9bd01b3ffec3ff35bfacb628257db8655ee5
      https://github.com/llvm/llvm-project/commit/dbea9bd01b3ffec3ff35bfacb628257db8655ee5
  Author: Amilendra Kodithuwakku <amilendra.kodithuwakku at arm.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M bolt/docs/conf.py

  Log Message:
  -----------
  [docs][bolt] Remove Markdown enum (#226411)

Remove use of Markdown enum from the bolt docs. Related to #223829.

This should fix our ATfL build
[failure](https://github.com/arm/arm-toolchain/actions/runs/36103090912/job/107969633028#step:7:22533)
```
Traceback (most recent call last):
  File "/workspace/python/.venv/lib/python3.12/site-packages/sphinx/config.py", line 529, in eval_config_file
    exec(code, namespace)  # NoQA: S102
    ^^^^^^^^^^^^^^^^^^^^^
  File "/workspace/src/bolt/docs/conf.py", line 18, in <module>
    globals().update(common_conf(tags, markdown=Markdown.NEVER))
                                                ^^^^^^^^
NameError: name 'Markdown' is not defined
```


  Commit: 126dbd97fc5d33edf43a1fce12fb5d3ea46e5be7
      https://github.com/llvm/llvm-project/commit/126dbd97fc5d33edf43a1fce12fb5d3ea46e5be7
  Author: Alexander Richardson <alexrichardson at google.com>
  Date:   2026-09-26 (Sat, 26 Sep 2026)

  Changed paths:
    M clang/test/CodeGen/RISCV/lto-module-asm-abi.c

  Log Message:
  -----------
  [Clang][RISC-V] Fix lto-module-asm-abi.c on non-asserts/no-lld builds (#226752)

Pass `-fno-discard-value-names` so the `entry:` label is preserved in
non-asserts builds, and drop `-fuse-ld=lld` so the driver check succeeds
on bots that do not have `ld.lld` installed.

Fixes: bf529329b5ce ("[RISC-V][LTO] Add baseline tests for LTO inline assembly and mapping symbols (#225129)")
Pull-Request: https://github.com/llvm/llvm-project/pull/226752


  Commit: 57721b7c631b3dacc8f59b2467992e3ff4866cc6
      https://github.com/llvm/llvm-project/commit/57721b7c631b3dacc8f59b2467992e3ff4866cc6
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M orc-rt/include/CMakeLists.txt
    M orc-rt/include/orc-rt-c/config.h.in
    A orc-rt/include/orc-rt-c/support/LogLevel.h
    M orc-rt/include/orc-rt-c/support/Logging.h
    M orc-rt/include/orc-rt/bedrock/Session.h

  Log Message:
  -----------
  [orc-rt] Move ORC_RT_LOG_ENABLED out of config.h; catch typos. (#226751)

Move ORC_RT_LOG_ENABLED to orc-rt-c/support/LogLevel.h so that config.h
is kept for build options only.

Switch to using function-like macros so that typos in level-names become
compilation errors.


  Commit: 689040ca0cb30b3f93edb5e51f64333b23e4610f
      https://github.com/llvm/llvm-project/commit/689040ca0cb30b3f93edb5e51f64333b23e4610f
  Author: Matt Arsenault <Matthew.Arsenault at amd.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/include/llvm/CodeGen/TargetLoweringObjectFileImpl.h
    M llvm/lib/CodeGen/TargetLoweringObjectFileImpl.cpp
    M llvm/lib/Target/M68k/M68kTargetObjectFile.cpp
    M llvm/lib/Target/M68k/M68kTargetObjectFile.h

  Log Message:
  -----------
  CodeGen: Remove shadowing TargetMachine members from COFF and M68k TLOFs (#226769)

TargetLoweringObjectFile::Initialize already records the TargetMachine
in a base class field.

Co-authored-by: Claude Opus 5 <noreply at anthropic.com>


  Commit: 9bf0c497dceba0c7eb882c0f2a96c8151ce74ae3
      https://github.com/llvm/llvm-project/commit/9bf0c497dceba0c7eb882c0f2a96c8151ce74ae3
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M orc-rt/include/orc-rt/bedrock/ConnectorRegistry.h
    M orc-rt/lib/bedrock/ConnectorRegistry.cpp
    M orc-rt/lib/bedrock/sys/posix/SocketConnector.cpp
    M orc-rt/test/unit/bedrock/sys/posix/SocketConnectorTest.cpp
    M orc-rt/tools/ogre/ogre.cpp

  Log Message:
  -----------
  [orc-rt] Simplify ConnectorRegistry::connect and ogre setup. (#226772)

ConnectorRegistry::connect and ConnectorFn now take the Session and
BootstrapInfo directly, replacing the GetAttachInfo callback and the
AttachInfo struct. The callback let the Session be built lazily, after
the connector had validated its spec, but a connection can fail after
validation anyway, so callers already had to handle discarding a Session
built for a failed connection. Build the Session first, then connect.

ogre's setup is restructured to match: makeSession detects the process
info, builds a thread-pool dispatcher and the Session, adds the host
services, then connects; runOgre waits for the detach. Errors are
reported via Session::logErrors when logging is enabled.

SocketConnectorTest now connects a real Session. Its ownership test
adopts a non-stream socket, which the connector accepts and
createSimpleRemoteCAOverSocket then rejects, rather than relying on a
failing GetAttachInfo.


  Commit: 80b46c9d74a868cd20720cc7932a2f88bda43d25
      https://github.com/llvm/llvm-project/commit/80b46c9d74a868cd20720cc7932a2f88bda43d25
  Author: Letu Ren <fantasquex at gmail.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M clang/test/CIR/CodeGenBuiltins/builtin-nondeterministic-value.c

  Log Message:
  -----------
  [CIR][NFC] Add vector of boolean test to __builtin_nondeterministic_value (#219550)

Assisted-by: grok-4.6
Signed-off-by: Letu Ren <fantasquex at gmail.com>


  Commit: dfde6ac69e6e0c5a717042de3fa7f118eea7d830
      https://github.com/llvm/llvm-project/commit/dfde6ac69e6e0c5a717042de3fa7f118eea7d830
  Author: Mamadou Wane <mamadouswane at gmail.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M clang-tools-extra/clang-tidy/bugprone/RedundantBranchConditionCheck.cpp
    M clang-tools-extra/docs/ReleaseNotes.md
    M clang-tools-extra/test/clang-tidy/checkers/bugprone/redundant-branch-condition.cpp

  Log Message:
  -----------
  [clang-tidy] Fix redundant-branch-condition false positive in loops (#225827)

Fixes #205685.

`bugprone-redundant-branch-condition` decides whether the condition
variable changes between the outer and inner `if` by comparing source
positions. When a loop sits between the two, a mutation that comes after
the inner `if` in the source still runs before the inner condition is
evaluated again on the next iteration, so the check reports a redundant
condition that isn't, and the fix-it changes behavior.

The fix walks the parents of the inner `if` up to the outer `if` and
finds the outermost enclosing loop. If the variable is mutated anywhere
in that loop, the check does not warn. This follows NagyDonat's
suggestion in the issue: the existing check already covers mutations
between the outer condition and the loop, so only the loop itself needs
the extra query. The walk passes through declarations, so an inner `if`
inside a lambda stored in a variable is handled too, and it stops at the
enclosing function. I chose a syntactic walk instead of the CFG
(`utils::ExprSequence`), since it covers the range the issue asks for
without building a CFG on every match.

Tests cover `for`, `while`, `do`, and range-based `for`, a mutation in a
`do`/`while` condition, a lambda stored in a variable inside the loop,
and an inner loop whose enclosing loop does the mutation. Each of these
warns without the patch. Three positive cases confirm the warning is
kept when the loop never mutates the variable, when the mutation comes
after the loop, and when the loop encloses both `if` statements.

Limitations:
- Any mutation in the loop suppresses the warning, including one
followed by an exit from the loop (`break`, `return`, `throw`) or one
that cannot make the condition false. The inner condition is still
redundant in those cases; telling them apart needs the CFG. I added the
`break` case under Unhandled Cases. The change only removes warnings, so
it adds no new false positives.
- Loops built with `goto` and Objective-C `for ... in` loops are not
recognized, so the false positive remains there.

I used Claude to help write the code. I tested and reviewed all of it
myself, and worked through the approach and suggestions with Claude.


  Commit: 719341a64c02261b7b43e4aa6a25f597cca8626d
      https://github.com/llvm/llvm-project/commit/719341a64c02261b7b43e4aa6a25f597cca8626d
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/include/llvm/Analysis/TargetTransformInfo.h
    M llvm/include/llvm/Analysis/TargetTransformInfoImpl.h
    M llvm/include/llvm/CodeGen/BasicTTIImpl.h
    M llvm/lib/Analysis/TargetTransformInfo.cpp
    M llvm/lib/Target/AArch64/AArch64TargetTransformInfo.cpp
    M llvm/lib/Target/AArch64/AArch64TargetTransformInfo.h
    M llvm/test/Analysis/CostModel/AArch64/speculative-load.ll
    M llvm/test/Analysis/CostModel/X86/speculative-load.ll

  Log Message:
  -----------
  [TTI] Provide conservative legality + costs for @llvm.speculative.load. (#180036)

Add TTI support for @llvm.speculative.load, including cost and legaltiy
checking support.

The initial implementation for AArch64 checks if the loaded type is
<= 16 bytes, and only considers such cases legal due to MTE.

PR: 
https://github.com/llvm/llvm-project/pull/180036


Depends on https://github.com/llvm/llvm-project/pull/179642


  Commit: 6909c17f14683203621f5a3d8fbf04dfd5d9c623
      https://github.com/llvm/llvm-project/commit/6909c17f14683203621f5a3d8fbf04dfd5d9c623
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Scalar/ConstraintElimination.cpp
    M llvm/test/Transforms/ConstraintElimination/analysis-invalidation.ll

  Log Message:
  -----------
  [ConstraintElim] Don't request SCEV if there are no loops. (NFC) (#226736)

ConstraintElimination only uses SCEV when there are any loops. Don't
request the analysis if there are no loops.

This reduces compile-time a bit (more for workloads with large number of
functions w/o loops):

stage1-O3: -0.03%
stage1-ReleaseThinLTO: -0.04%
stage1-ReleaseLTO-g: -0.02%
stage1-aarch64-O3: -0.03%
stage2-O3: -0.04%
stage2-clang: -0.09%


https://llvm-compile-time-tracker.com/compare.php?from=899d817c7950c997402cd229935cd822acf45b08&to=c4453240417d8705b0752c3feda8d02365f8175c&stat=instructions:u

PR: https://github.com/llvm/llvm-project/pull/226736


  Commit: 57630fd809ca4964f887dd531e1a09618d962b10
      https://github.com/llvm/llvm-project/commit/57630fd809ca4964f887dd531e1a09618d962b10
  Author: Chibuoyim (Wilson) Ogbonna <chibuoyim.faith.ogbonna at huawei.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    R clang/test/CodeGen/AArch64/sve-intrinsics/acle_sve_addv.c
    A clang/test/CodeGen/AArch64/sve/addv.c

  Log Message:
  -----------
  [clang][CIR] Add tests for SVE ADDV intrinsics (#225648)

This adds CIR tests for `svaddv` (plain SVE) intrinsics following the
task description in
[223963](https://github.com/llvm/llvm-project/issues/223963).

Moves and adapts `sve-intrinsics/acle_sve_addv.c` to `sve/addv.c`.


  Commit: 68fddbbe019b63698e9c4a898b313b9112019cab
      https://github.com/llvm/llvm-project/commit/68fddbbe019b63698e9c4a898b313b9112019cab
  Author: David Green <david.green at arm.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/lib/CodeGen/SelectionDAG/LegalizeTypes.h
    M llvm/lib/CodeGen/SelectionDAG/LegalizeVectorTypes.cpp
    M llvm/test/CodeGen/AArch64/lowmaskedlanes.ll

  Log Message:
  -----------
  [DAG] Scalarise trivial splat operations (#226257)

This fixes an issue reported on #224255, where a single active lane
masked store is converted to a v1f16 extract_subvector, which becomes a
v1f16 splat, which fails to scalarize. Add the necessary trivial
scalarisation of the splat by using the f16 input operand.

(I was originally going to fix this by generating a scalar f16 extract
directly (which would have the benefit of treating f16 as legal), but
that seems to cause a regression in 2 x86 tests).


  Commit: 6b51046ae30cd78fc4b26605e2dcf3b70c282f4c
      https://github.com/llvm/llvm-project/commit/6b51046ae30cd78fc4b26605e2dcf3b70c282f4c
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/SLPVectorizer.cpp
    A llvm/test/Transforms/SLPVectorizer/X86/narrowed-reduction-gathered-leftover-leaf.ll

  Log Message:
  -----------
  [SLP]Fix erasing gathered leftover narrowed reduction leaves

A leftover narrowed reduction leaf, only gathered in the tree, loses all
users once the tree scalars are erased and is swept as a dead operand,
though the reduction epilogue still uses it. Keep such values alive.

Fixes https://github.com/llvm/llvm-project/pull/224919#issuecomment-5855368565

Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/226782


  Commit: a9407d59c4abfb8bf49da7dfcec6775707288b9e
      https://github.com/llvm/llvm-project/commit/a9407d59c4abfb8bf49da7dfcec6775707288b9e
  Author: Nico Weber <thakis at chromium.org>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M libcxx/include/__ostream/print.h

  Log Message:
  -----------
  [libc++] Port #200996 to ostream (#226372)

Reduces the time to compile a TU with just `#include <ostream>` from
254.7 ms ± 3.0 ms to 227.7 ms ± 2.1 ms on my system (-std=c++23, -O2,
arm64 macOS).

See #195466 for details. Without this, the call is evaluated when the
template is parsed, which evaluates format_string's consteval
constructor for "\n" in every translation unit that includes <ostream>,
even if nothing calls println().

No behavior change.


  Commit: 14df65f5db67d0096ef2360abb1e30891dae66b5
      https://github.com/llvm/llvm-project/commit/14df65f5db67d0096ef2360abb1e30891dae66b5
  Author: Leonidas Spyropoulos <artafinde at gmail.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M libcxx/include/__chrono/duration.h
    M libcxx/test/std/time/months.pass.cpp
    M libcxx/test/std/time/years.pass.cpp

  Log Message:
  -----------
  [libc++][chrono] Fix years/months periods on GCC/i386 (#223669)

`static_cast<int>(365.2425 * 60 * 60 * 24)`, added in
f537b4e51822b19780386e0575ff95e82f8ec445, isn't exactly 31556952 on
every host: GCC targeting i386 folds it in x87 extended precision and
gets 31556951, making `years::period` and `months::period` coprime and
breaking `year_month` arithmetic.

Use the literal values instead, there's no readability to lose since
they were only there to avoid a template instantiation in the first
place.

Signed-off-by: Leonidas Spyropoulos <artafinde at archlinux.org>


  Commit: 0b401e859b9fec54231b11ffb39085ea02e053c0
      https://github.com/llvm/llvm-project/commit/0b401e859b9fec54231b11ffb39085ea02e053c0
  Author: Kazu Hirata <kazu at google.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/lib/Target/Hexagon/HexagonConstPropagation.cpp
    M llvm/lib/Target/PowerPC/PPC.h
    M llvm/tools/dsymutil/DwarfLinkerForBinary.h
    M llvm/tools/llvm-cov/CodeCoverage.cpp
    M llvm/tools/llvm-objdump/COFFDump.h
    M llvm/tools/llvm-objdump/ELFDump.h
    M llvm/tools/llvm-objdump/OffloadDump.cpp
    M llvm/tools/llvm-objdump/WasmDump.h
    M llvm/tools/llvm-profgen/PerfReader.h

  Log Message:
  -----------
  [llvm] Remove declarations without definitions (NFC) (#226764)

HexagonConstEvaluator::evaluateHexVector2: Added on July 28, 2016 in
commit 167d918225ecd05a63f6b8d449c317feda741e18 without a definition or
any callers.

initializePPCExpandISELPass: The definition and caller were removed on
August 27, 2024 in commit 8e901c255df45e38cb1d69a576804029e20868bf.

dsymutil::DwarfLinkerForBinary::createStreamer: The definition and
caller were removed on April 1, 2023 in commit
36f351098cd50809658493d9b2e22a795874bab0 (when the non-template
declaration in DwarfLinkerForBinary.h was replaced with a template
declaration without a definition).

exportCoverageDataToJson: The definition and caller were replaced with
CoverageExporterJson on January 4, 2018 in commit
1ef3a778ac47564aa5a7f04bbf572d22d1c616fb.

objdump::printCOFFFileHeader, objdump::printELFFileHeader, and
objdump::printWasmFileHeader: The definitions and callers were replaced
with Dumper::printPrivateHeaders on July 14, 2023 in commit
0af663f80da0009f6fd879cf4d41743d4c88a2db.

disassembleObject: Added on May 23, 2025 in commit
51a03ed27282166d418399f2ade9814ea5be9944 without a definition or any
callers.

sampleprof::VirtualUnwinder::recordRangeCount: The definition and
callers were removed on January 11, 2021 in commit
3869309a0c92735228afaa5663d1c10bb372bb54.

Assisted-by: Antigravity


  Commit: 1345a4fa8d60bdd33d59b7a1c0613eaef7d8e01f
      https://github.com/llvm/llvm-project/commit/1345a4fa8d60bdd33d59b7a1c0613eaef7d8e01f
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    A llvm/test/Transforms/SLPVectorizer/X86/extracted-subfields-shifted-trunc.ll

  Log Message:
  -----------
  [SLP][NFC]Add an extra test witj missing vectorization, NFC



Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/226802


  Commit: 0f5a125bad555b6bf4bb2318b9f1ea7936adf19d
      https://github.com/llvm/llvm-project/commit/0f5a125bad555b6bf4bb2318b9f1ea7936adf19d
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    A libcxx/docs/ABIGuarantees.md
    R libcxx/docs/ABIGuarantees.rst
    A libcxx/docs/AddingNewCIJobs.md
    R libcxx/docs/AddingNewCIJobs.rst
    A libcxx/docs/CodingGuidelines.md
    R libcxx/docs/CodingGuidelines.rst
    A libcxx/docs/Contributing.md
    R libcxx/docs/Contributing.rst
    A libcxx/docs/Contributing/NewStandardProcedure.md
    R libcxx/docs/Contributing/NewStandardProcedure.rst
    A libcxx/docs/Contributing/PostMeetingProcedure.md
    R libcxx/docs/Contributing/PostMeetingProcedure.rst
    A libcxx/docs/Contributing/ReleaseProcedure.md
    R libcxx/docs/Contributing/ReleaseProcedure.rst
    A libcxx/docs/DesignDocs/ABIVersioning.md
    R libcxx/docs/DesignDocs/ABIVersioning.rst
    A libcxx/docs/DesignDocs/AtomicDesign.md
    R libcxx/docs/DesignDocs/AtomicDesign.rst
    A libcxx/docs/DesignDocs/CapturingConfigInfo.md
    R libcxx/docs/DesignDocs/CapturingConfigInfo.rst
    A libcxx/docs/DesignDocs/ExperimentalFeatures.md
    R libcxx/docs/DesignDocs/ExperimentalFeatures.rst
    A libcxx/docs/DesignDocs/ExtendedCXX03Support.md
    R libcxx/docs/DesignDocs/ExtendedCXX03Support.rst
    A libcxx/docs/DesignDocs/FeatureTestMacros.md
    R libcxx/docs/DesignDocs/FeatureTestMacros.rst
    A libcxx/docs/DesignDocs/FileTimeType.md
    R libcxx/docs/DesignDocs/FileTimeType.rst
    A libcxx/docs/DesignDocs/HeaderRemovalPolicy.md
    R libcxx/docs/DesignDocs/HeaderRemovalPolicy.rst
    M libcxx/include/__configuration/abi.h

  Log Message:
  -----------
  [libc++][docs] Rename documentation files to Markdown (batch 1) (#221512)

Tracking issue: #201242
See the [migration guide] for more information. 

[migration guide]:
https://llvm.org/docs/SphinxQuickstartTemplate.html#markdown-migration-guidelines

This is the initial straight rename commit. It will probably break the
docs build, but it has to be a separate PR for blame preservation
purposes.


  Commit: 61b428e0edfe674b84d77f7b55aa687fce3b501e
      https://github.com/llvm/llvm-project/commit/61b428e0edfe674b84d77f7b55aa687fce3b501e
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M libcxx/docs/ABIGuarantees.md
    M libcxx/docs/AddingNewCIJobs.md
    M libcxx/docs/CodingGuidelines.md
    M libcxx/docs/Contributing.md
    M libcxx/docs/Contributing/NewStandardProcedure.md
    M libcxx/docs/Contributing/PostMeetingProcedure.md
    M libcxx/docs/Contributing/ReleaseProcedure.md
    M libcxx/docs/DesignDocs/ABIVersioning.md
    M libcxx/docs/DesignDocs/AtomicDesign.md
    M libcxx/docs/DesignDocs/CapturingConfigInfo.md
    M libcxx/docs/DesignDocs/ExperimentalFeatures.md
    M libcxx/docs/DesignDocs/ExtendedCXX03Support.md
    M libcxx/docs/DesignDocs/FeatureTestMacros.md
    M libcxx/docs/DesignDocs/FileTimeType.md
    M libcxx/docs/DesignDocs/HeaderRemovalPolicy.md
    M libcxx/docs/conf.py

  Log Message:
  -----------
  [libc++][docs] Convert documentation from reST to Markdown (batch 1) (#221513)

This is the first batch of changes to migrate libc++ documentation from
rst to markdown.

I use a local pixel diff tool to compare the rendered HTML, and all
diffs seem like fixes. They tend to fall into the following categories:

- dashed bullet lists were previously not rendered, but now they are
- extra indentation interpreted as blockquotes has been removed
- single backticks are now codefont spans, not italic spans

Tracking issue: #201242
See the [migration guide] for more information. 

[migration guide]:
https://llvm.org/docs/SphinxQuickstartTemplate.html#markdown-migration-guidelines
This is a stacked PR based on #221512, which will be a standalone commit
that
renames *.rst -> *.md before this PR lands for history preservation
purposes.

-----

Before/after validation links:
| Source file | Before HTML | After HTML |
| --- | --- | --- |
| `libcxx/docs/ABIGuarantees.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/ABIGuarantees.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/ABIGuarantees.html)
|
| `libcxx/docs/AddingNewCIJobs.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/AddingNewCIJobs.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/AddingNewCIJobs.html)
|
| `libcxx/docs/CodingGuidelines.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/CodingGuidelines.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/CodingGuidelines.html)
|
| `libcxx/docs/Contributing/NewStandardProcedure.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/Contributing/NewStandardProcedure.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/Contributing/NewStandardProcedure.html)
|
| `libcxx/docs/Contributing/PostMeetingProcedure.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/Contributing/PostMeetingProcedure.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/Contributing/PostMeetingProcedure.html)
|
| `libcxx/docs/Contributing/ReleaseProcedure.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/Contributing/ReleaseProcedure.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/Contributing/ReleaseProcedure.html)
|
| `libcxx/docs/Contributing.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/Contributing.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/Contributing.html)
|
| `libcxx/docs/DesignDocs/ABIVersioning.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/DesignDocs/ABIVersioning.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/DesignDocs/ABIVersioning.html)
|
| `libcxx/docs/DesignDocs/AtomicDesign.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/DesignDocs/AtomicDesign.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/DesignDocs/AtomicDesign.html)
|
| `libcxx/docs/DesignDocs/CapturingConfigInfo.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/DesignDocs/CapturingConfigInfo.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/DesignDocs/CapturingConfigInfo.html)
|
| `libcxx/docs/DesignDocs/ExperimentalFeatures.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/DesignDocs/ExperimentalFeatures.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/DesignDocs/ExperimentalFeatures.html)
|
| `libcxx/docs/DesignDocs/ExtendedCXX03Support.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/DesignDocs/ExtendedCXX03Support.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/DesignDocs/ExtendedCXX03Support.html)
|
| `libcxx/docs/DesignDocs/FeatureTestMacros.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/DesignDocs/FeatureTestMacros.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/DesignDocs/FeatureTestMacros.html)
|
| `libcxx/docs/DesignDocs/FileTimeType.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/DesignDocs/FileTimeType.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/DesignDocs/FileTimeType.html)
|
| `libcxx/docs/DesignDocs/HeaderRemovalPolicy.md` |
[before](https://llvmdocs.staging.reidkleckner.dev/before/libcxx/docs/DesignDocs/HeaderRemovalPolicy.html)
|
[after](https://llvmdocs.staging.reidkleckner.dev/after/libcxx/docs/DesignDocs/HeaderRemovalPolicy.html)
|


  Commit: 6cff1c56d1678e3d7eb70650d1fe138eac80c05e
      https://github.com/llvm/llvm-project/commit/6cff1c56d1678e3d7eb70650d1fe138eac80c05e
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/SLPVectorizer/SLPUtils.cpp
    M llvm/test/Transforms/SLPVectorizer/X86/extracted-subfields-shifted-trunc.ll

  Log Message:
  -----------
  [SLP]Look through truncation of shifted extracted sub-fields

The masked sub-field of the shifted truncation of a wider scalar was
matched with the truncation as its source, while the other fields
matched the scalar itself, so the gather of the fields was rejected.
The field is within the truncated bits, look through the truncation.

Fixes #74380

Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/226803


  Commit: 20bbd88cf9e7be286b25c29c877c2d0564da9ecf
      https://github.com/llvm/llvm-project/commit/20bbd88cf9e7be286b25c29c877c2d0564da9ecf
  Author: Guy David <guyda96 at gmail.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Utils/SimplifyCFG.cpp
    A llvm/test/Transforms/SimplifyCFG/AArch64/speculate-vector-phi-select-cost.ll
    A llvm/test/Transforms/SimplifyCFG/ARM/speculate-vector-phi-select-cost.ll
    A llvm/test/Transforms/SimplifyCFG/RISCV/speculate-mask-phi-select-cost.ll
    A llvm/test/Transforms/SimplifyCFG/X86/speculate-mask-phi-select-cost.ll

  Log Message:
  -----------
  [SimplifyCFG] Cost speculated selects with their real scalar condition (#217664)

`validateAndCostRequiredSelects()` priced the selects that
`speculativelyExecuteBB()` would create using
`CmpInst::makeCmpResultType(PN->getType())` as the condition type. For a
vector phi, that asks the target for the cost of a per-lane vector
select, but the select actually created uses the branch condition, which
is always a scalar `i1`.

This only changes behaviour where a target's cost model distinguishes
the two condition types. Of the targets checked, only AArch64 does.

This may worsen the compiler's output in RISC-V, X86, ARM, so no
intention to merge soon before collecting more feedback on how the
different targets should communicate this property.


  Commit: f8cfaa7dc0caf6bd51b82798718c51ac3fd68c12
      https://github.com/llvm/llvm-project/commit/f8cfaa7dc0caf6bd51b82798718c51ac3fd68c12
  Author: Jake Egan <Jake.egan at ibm.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M libcxx/test/configs/ibm-libc++-shared.cfg.in

  Log Message:
  -----------
  [libc++][AIX] Add system library path via blibpath for lldb (#223837)

On AIX some tools we use for testing libc++, like lldb, are linked
against the system libc++, which has additional members (e.g
`shr2_64.o`) that the newly built libc++.a doesn't have. But the current
test harness set the `LIBPATH` to point at the newly built libc++, which
can load break these tools.

This change removes the `LIBPATH` and instead sets the `blibpath`
(equivalent to rpath on other systems), which helps lldb find the system
libc++.a, while still running the tests against the libc++ build under
test.


  Commit: db9f06ce021c54523afc8bf9d0cfe45aba2eba09
      https://github.com/llvm/llvm-project/commit/db9f06ce021c54523afc8bf9d0cfe45aba2eba09
  Author: Fangrui Song <i at maskray.me>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/lib/Target/AArch64/AArch64CodeLayoutOpt.cpp
    M llvm/lib/Transforms/Instrumentation/AddressSanitizer.cpp

  Log Message:
  -----------
  Remove cl::callback from AArch64CodeLayoutOpt and AddressSanitizer (#226757)

cl::callback will be removed to enable migration to TableGen based
representation

LLM-aided


  Commit: 8e6f2603dc5d4a93400aa8ba28ea624644be0c9a
      https://github.com/llvm/llvm-project/commit/8e6f2603dc5d4a93400aa8ba28ea624644be0c9a
  Author: Fangrui Song <i at maskray.me>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/include/llvm/ADT/DenseMap.h
    M llvm/include/llvm/ADT/DenseMapInfo.h
    M llvm/lib/Support/CMakeLists.txt
    A llvm/lib/Support/DenseMap.cpp
    M llvm/unittests/ADT/DenseMapTest.cpp
    M llvm/utils/gn/secondary/llvm/lib/Support/BUILD.gn

  Log Message:
  -----------
  [DenseMap] Share rehash and grow for relocatable bucket types. NFC (#225018)

DenseMap is heavily instantiated and moveFrom and grow are among the
largest code families. For trivially copy constructible and destructible
bucket types (also satisfied by std::pair), call an out-of-line
`growRelocatable` with size/align/hasher (dictionary passing style).

A pointer key hashed by its value hashes inline, which a null
BucketHasher asks for, sparing a call per entry.
DenseMapInfo<T *>::PointerValueHash names the class declaring it, so an
info that specializes or inherits it to hash the pointee -- Attributor's
InstExclusionSet, VPCSEDenseMapInfo, MachineInstrExpressionTrait --
keeps its own hash. Any other key hashes through a thunk, one per
(KeyT, KeyInfoT) whatever the map's value type.

SmallDenseMap's in-place rehash for remove_if shares the loop through
`rehashRelocatable`. It rehashes once rather than into a temporary map
and back, which can reorder a probe chain that wraps around the table.

Building clang takes 0.86% fewer instructions and the binary is 0.64%
smaller.

Aided by Opus 5


  Commit: 9e44a6664500bcc01fb9ddc35710b4d0fd748b06
      https://github.com/llvm/llvm-project/commit/9e44a6664500bcc01fb9ddc35710b4d0fd748b06
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/test/Transforms/SLPVectorizer/X86/extracted-subfields.ll

  Log Message:
  -----------
  [SLP][NFC]Add extra tests with incorrect vectorization, NFC



Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/226827


  Commit: eea552937b1e30c8b74bf3748cccab1357dd0d57
      https://github.com/llvm/llvm-project/commit/eea552937b1e30c8b74bf3748cccab1357dd0d57
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/SLPVectorizer.cpp
    M llvm/test/Transforms/SLPVectorizer/X86/extracted-subfields.ll

  Log Message:
  -----------
  [SLP]Fix reused scales for sub-fields gathered in natural order

The reduction root sub-fields were emitted in the natural order, but the
reused values were scaled by the original lane order. Reorder the root
scalars instead.

Fixes https://github.com/llvm/llvm-project/pull/224919#issuecomment-5858504241

Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/226828


  Commit: d0ea8a8e46091f71684091f48412ce500165d76f
      https://github.com/llvm/llvm-project/commit/d0ea8a8e46091f71684091f48412ce500165d76f
  Author: Martin Storsjö <martin at martin.st>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/unittests/Support/LLVMToolSession/LLVMToolSessionTest.cpp

  Log Message:
  -----------
  [unittests] Fix a recent test on Windows with LLVM_WINDOWS_PREFER_FORWARD_SLASH (#224963)

This fixes errors like these:
```
Expected equality of these values:
  Context.Path
    Which is: "D:/a/llvm-mingw/llvm-mingw/llvm-project/build/unittests/Support/LLVMToolSession/./LLVMToolSessionTests.exe"
  ExecutablePath.c_str()
    Which is: "D:\\a\\llvm-mingw\\llvm-mingw\\llvm-project\\build\\unittests\\Support\\LLVMToolSession\\.\\LLVMToolSessionTests.exe"
```


  Commit: df7a21f8210426653d12c50475651c4d7518b804
      https://github.com/llvm/llvm-project/commit/df7a21f8210426653d12c50475651c4d7518b804
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/LoopVectorize.cpp
    M llvm/lib/Transforms/Vectorize/VPlanConstruction.cpp
    M llvm/lib/Transforms/Vectorize/VPlanTransforms.h

  Log Message:
  -----------
  [LV] Remove EpilogueLoopVectorizationInfo::EpilogueUF (NFC). (#226792)

The epilogue vector loop is always unrolled by 1: the only construction
site passes 1 and the constructor asserted it. Drop the field and use 1
directly at its users, and drop the now always 1 EpilogueUF parameter of
addMinimumVectorEpilogueIterationCheck.

Clean-up in preparation for removing/simplifying
EpilogueLoopVectorizationInfo.


  Commit: d8b43a8db3cd5314e5c9cc51af04fca342715187
      https://github.com/llvm/llvm-project/commit/d8b43a8db3cd5314e5c9cc51af04fca342715187
  Author: Matt Arsenault <Matthew.Arsenault at amd.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/lib/Target/Mips/MipsAsmPrinter.cpp
    M llvm/lib/Target/Mips/MipsSubtarget.cpp
    M llvm/lib/Target/Mips/MipsSubtarget.h
    M llvm/lib/Target/Mips/MipsTargetMachine.cpp
    M llvm/lib/Target/Mips/MipsTargetMachine.h
    A llvm/test/CodeGen/Mips/target-abi-module-flag.ll

  Log Message:
  -----------
  Mips: Properly account for target-abi in subtarget construction (#226721)


  Commit: 5ad4959a040a6e31eba7ab46f3bf4fd41cd224dc
      https://github.com/llvm/llvm-project/commit/5ad4959a040a6e31eba7ab46f3bf4fd41cd224dc
  Author: Kazu Hirata <kazu at google.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M clang/include/clang/AST/ASTContext.h
    M clang/include/clang/AST/NestedNameSpecifierBase.h
    M clang/lib/AST/NestedNameSpecifier.cpp

  Log Message:
  -----------
  [clang] Unique NamespaceAndPrefixStorages with a UniquingSet (NFC) (#224221)

This patch migrates NamespaceAndPrefixStorages in ASTContext from
llvm::FoldingSet to llvm::UniquingSet.

NamespaceAndPrefixStorage keys on a pair of const NamespaceBaseDecl *
and NestedNameSpecifier.  Switching to UniquingSet allows us to look
up storages with a typed key, eliminating FoldingSetNodeID
serialization at lookup sites and removing
NamespaceAndPrefixStorage::Profile.

Assisted-by: Antigravity


  Commit: 15eef1398e36befcaaf6cc19872805f6eb3ae5a4
      https://github.com/llvm/llvm-project/commit/15eef1398e36befcaaf6cc19872805f6eb3ae5a4
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/include/llvm/ExecutionEngine/Orc/Debugging/PerfSupportPlugin.h
    M llvm/include/llvm/ExecutionEngine/Orc/Debugging/VTuneSupportPlugin.h
    M llvm/lib/ExecutionEngine/Orc/Debugging/PerfSupportPlugin.cpp
    M llvm/lib/ExecutionEngine/Orc/Debugging/VTuneSupportPlugin.cpp

  Log Message:
  -----------
  [ORC] Call Perf/VTune support wrappers through Proxies (#226677)

Hold PerfSupportPlugin's start/end registration wrappers and
VTuneSupportPlugin's unregister wrapper as Proxy members, replacing
their callSPSWrapper calls. Each proxy is built in the constructor from
the address it already takes, so the constructor signatures are
unchanged. The Perf impl and VTune register wrappers are only used as
alloc-action tags and stay ExecutorAddrs.


  Commit: dbde1428562362792d85cb9bbb58415f1b21cb48
      https://github.com/llvm/llvm-project/commit/dbde1428562362792d85cb9bbb58415f1b21cb48
  Author: Jared Wyles <jared.wyles at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M orc-rt/test/regression/jit-free-foundations/check-rt-process-info.test
    M orc-rt/test/regression/lit.cfg.py

  Log Message:
  -----------
  [orc-rt] Fixing linux tests to enable CI (#226766)


  Commit: a432c764f54c72f60bb1c2df0c050e5cc29db2dd
      https://github.com/llvm/llvm-project/commit/a432c764f54c72f60bb1c2df0c050e5cc29db2dd
  Author: Ben Shi <2283975856 at qq.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Target/X86/X86RegisterInfo.td

  Log Message:
  -----------
  [X86][NFC] Simplify definition of TMM registers (#226779)


  Commit: 6c75b015778cdb22d688d6c6f6e40ccb6d9eb352
      https://github.com/llvm/llvm-project/commit/6c75b015778cdb22d688d6c6f6e40ccb6d9eb352
  Author: Letu Ren <fantasquex at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M mlir/include/mlir/Dialect/LLVMIR/LLVMIntrinsicOps.td
    M mlir/test/Dialect/LLVMIR/roundtrip.mlir
    M mlir/test/Target/LLVMIR/Import/intrinsic.ll
    M mlir/test/Target/LLVMIR/llvmir-intrinsics.mlir

  Log Message:
  -----------
  [mlir][LLVM] Add smulh and umulh intrinsics. (#226776)

Assisted-by: grok-4.7
Signed-off-by: Letu Ren <fantasquex at gmail.com>


  Commit: cef4b65cbd0d960b7ab8aa19654be28f5a5f830e
      https://github.com/llvm/llvm-project/commit/cef4b65cbd0d960b7ab8aa19654be28f5a5f830e
  Author: Harrison Hao <57025411+harrisonGPU at users.noreply.github.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Target/AMDGPU/AMDGPUInstCombineIntrinsic.cpp
    M llvm/test/Transforms/InstCombine/AMDGPU/llvm.amdgcn.dot.ll

  Log Message:
  -----------
  [AMDGPU][InstCombine] Fold zero dot operands to accumulator (#225003)

Fold AMDGPU dot intrinsics when either operand is zero.

`dot(a, 0) = 0` and `dot(0, b) = 0`, so replace the intrinsic with its
accumulator.
This avoids unrelated clamp and add/sub reassociation cases.


  Commit: 373c54d763c98487df27599247412f80d933e177
      https://github.com/llvm/llvm-project/commit/373c54d763c98487df27599247412f80d933e177
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M orc-rt/test/regression/jit-free-foundations/check-rt-process-info.test
    M orc-rt/test/tools/orc-rt-process-info-check.cpp

  Log Message:
  -----------
  [orc-rt] Prefix test tool output, update test. (#226862)

Prefix the triple, page-size, and cpu-features lines of the
orc-rt-process-info-check. The prefixes can be used to ensure that the
test doesn't try to match patterns against the wrong lines.

Also relaxes the feature string check to allow an empty feature string.


  Commit: 795457f653fb5e9f769678ed025ecb63d7bfbf53
      https://github.com/llvm/llvm-project/commit/795457f653fb5e9f769678ed025ecb63d7bfbf53
  Author: Fangrui Song <i at maskray.me>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/include/llvm/BinaryFormat/ELF.h
    M llvm/include/llvm/Object/ELFTypes.h
    M llvm/lib/MC/ELFObjectWriter.cpp

  Log Message:
  -----------
  [MC] Add ELF::getSymbolInfo and fix bitwise OR between enumeration types. NFC (#226860)

`ELF::STT_FILE | ELF::STB_LOCAL` puts the binding in the type bits,
which only works because STB_LOCAL is 0.

It combines enumerators from two distinct unnamed enums, which is
deprecated in C++20 and ill-formed in C++26 (P2864R2).


  Commit: d34c0c8bdcd3c718eb1f4b125a44bd3863dd3ef6
      https://github.com/llvm/llvm-project/commit/d34c0c8bdcd3c718eb1f4b125a44bd3863dd3ef6
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M orc-rt/test/regression/jit-free-foundations/check-rt-process-info.test
    M orc-rt/test/regression/lit.cfg.py

  Log Message:
  -----------
  [orc-rt] Rename os-version substitution. (#226863)

This substitution is available and being tested on all platforms. It's
currently only populated on Darwin, but may be useful on other
platforms, so rename it to reflect its role.


  Commit: 372dc97670f7b3ce422dc26e5f626b2711426e8d
      https://github.com/llvm/llvm-project/commit/372dc97670f7b3ce422dc26e5f626b2711426e8d
  Author: ykiko <ykiko at clice.io>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M libcxx/include/__format/buffer.h
    A libcxx/test/std/utilities/format/format.functions/bug_154670.pass.cpp

  Log Message:
  -----------
  [libc++][format] Don't leave the output buffer full after a bulk write (#226791)

__output_buffer::push_back writes a code unit before it makes room, so
the buffer must always have a free one. __copy, __transform and __fill
write in chunks of the available space and could end with the buffer
full. Formatting into a back_insert_iterator of a string, vector or
deque goes through a 256 code unit buffer, so an argument or fill whose
length is a multiple of 256, followed by a literal, wrote that literal
past the end of the buffer.

Make room in a full buffer at the end of these functions, as push_back
does.

Fixes #154670


  Commit: 6bc9070d58e6b1396f380fcc48234e49ede900f8
      https://github.com/llvm/llvm-project/commit/6bc9070d58e6b1396f380fcc48234e49ede900f8
  Author: Nico Weber <thakis at chromium.org>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M clang/lib/Sema/SemaOverload.cpp

  Log Message:
  -----------
  [clang] clang-format two constructors (#226737)

I'd like to change these two in a patch, and the diff looks a bit
confusing since they aren't formatted yet. So format them in a prep
commit to make the diff clearer.

No behavior change.


  Commit: af39a0147d97320ccf9de1ca4a58f92a519ecbff
      https://github.com/llvm/llvm-project/commit/af39a0147d97320ccf9de1ca4a58f92a519ecbff
  Author: Nico Weber <thakis at chromium.org>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/utils/gn/secondary/clang/lib/ScalableStaticAnalysis/Analyses/BUILD.gn
    M llvm/utils/gn/secondary/clang/unittests/ScalableStaticAnalysis/BUILD.gn

  Log Message:
  -----------
  [gn build] Port ea0493b90c03 (#226870)


  Commit: 3e36b024db71848df98de3124953316c49dd9131
      https://github.com/llvm/llvm-project/commit/3e36b024db71848df98de3124953316c49dd9131
  Author: Nico Weber <thakis at chromium.org>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/utils/gn/secondary/libcxx/include/BUILD.gn

  Log Message:
  -----------
  [gn build] Port 7e91ef5d6aea (#226869)


  Commit: fb720063a6a01d1d31c8ac1b9318e5259110be58
      https://github.com/llvm/llvm-project/commit/fb720063a6a01d1d31c8ac1b9318e5259110be58
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M orc-rt/test/regression/README.md
    M orc-rt/test/regression/jit-free-foundations/lit.local.cfg
    M orc-rt/test/regression/languages/c/lit.local.cfg
    M orc-rt/test/regression/languages/c/return-zero.c
    M orc-rt/test/regression/lit.cfg.py
    M orc-rt/test/regression/object-formats/lit.local.cfg
    M orc-rt/test/regression/object-formats/mach-o/arm64/return-zero.s

  Log Message:
  -----------
  [orc-rt] Rename lit %{jit} substitution to %{obj-jit}. (#226867)

This substitution jit-loads object files via llvm-jitlink. Future tests,
e.g. for lazy compilation, may want to JIT from other representations
and will need different substitutions. Rename now to make the intent
clear and save us renaming later.


  Commit: c52392a6f464e5aa6bff198e4056ca58e43e0656
      https://github.com/llvm/llvm-project/commit/c52392a6f464e5aa6bff198e4056ca58e43e0656
  Author: aokblast <aokblast at FreeBSD.org>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M clang/lib/AST/ByteCode/Compiler.cpp
    M clang/lib/AST/ByteCode/Interp.cpp
    M clang/lib/AST/ByteCode/Interp.h
    M clang/lib/AST/ByteCode/Opcodes.td
    M clang/lib/AST/ExprConstant.cpp
    A clang/test/SemaCXX/new-nothrow-by-value.cpp

  Log Message:
  -----------
  [Clang][ExprConst] Drop PRValue for nothrow new (#226753)

A user defined operator new can accept prvalue for nothrow. However, it
should not be a ConstExpr. Early returns by
isUsableAsGlobalAllocationFunctionInConstantEvaluation instead of doing
LValue evaluation.
Also, move CheckPlacement new logic into new OpCode. This decouples
checking from Interp.cpp to Compiler.cpp.


  Commit: b1f5907d79d1d52ca5e938875ca4018ed6fb8bd7
      https://github.com/llvm/llvm-project/commit/b1f5907d79d1d52ca5e938875ca4018ed6fb8bd7
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/tools/llvm-jitlink/llvm-jitlink.cpp

  Log Message:
  -----------
  [llvm-jitlink] Call __orc_rt_run_program_wrapper through a Proxy (#226859)

Replace runWithRuntime's callSPSWrapper call with a Proxy.


  Commit: bebb7fe62f8883d822f084687cfb84c5cfe12bbb
      https://github.com/llvm/llvm-project/commit/bebb7fe62f8883d822f084687cfb84c5cfe12bbb
  Author: Timm Baeder <tbaeder at redhat.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M clang/include/clang/AST/APValue.h
    M clang/include/clang/AST/CharUnits.h
    M clang/lib/AST/APValue.cpp
    M clang/lib/AST/ASTContext.cpp
    M clang/lib/AST/ExprConstant.cpp

  Log Message:
  -----------
  [clang][NFC] Pass/Return `CharUnits` by value (#226115)

`CharUnits` is just an `int64_t`, but passed around by const reference
for some reason.

Also update the `CharUnits` documentation since we touch most of the
lines anyway (due to clang-format).


  Commit: b1f66905515904d048c9c53e92b1c0d2423aca19
      https://github.com/llvm/llvm-project/commit/b1f66905515904d048c9c53e92b1c0d2423aca19
  Author: Sairudra More <sairudra60 at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M flang/docs/OpenMPSupport.md
    M flang/lib/Lower/OpenMP/OpenMP.cpp
    A flang/test/Integration/OpenMP/allocate-clause-equivalence.f90
    A flang/test/Integration/OpenMP/scope-allocate-clause.f90
    M flang/test/Lower/OpenMP/Todo/allocate-clause-unsupported.f90
    A flang/test/Lower/OpenMP/Todo/scope-allocate-clause-unsupported.f90
    M flang/test/Lower/OpenMP/scope.f90
    M flang/test/Lower/OpenMP/target-scope.f90
    M mlir/lib/Dialect/OpenMP/IR/OpenMPDialect.cpp
    M mlir/lib/Target/LLVMIR/Dialect/OpenMP/OpenMPToLLVMIRTranslation.cpp
    M mlir/test/Dialect/OpenMP/invalid.mlir
    M mlir/test/Dialect/OpenMP/ops.mlir
    M mlir/test/Target/LLVMIR/openmp-allocate-clause.mlir
    A mlir/test/Target/LLVMIR/openmp-scope-allocate-clause.mlir
    M mlir/test/Target/LLVMIR/openmp-todo.mlir

  Log Message:
  -----------
  [flang][OpenMP] Support allocate clauses on scope constructs (#221229)

Flang already lowers OpenMP 5.2 `allocate` clauses on `scope` constructs
to `omp.scope`, but LLVM IR translation previously rejected them.

This change maps allocation operands to their corresponding private or
firstprivate slots and reuses the existing allocator-backed
private-storage and OpenMPIRBuilder allocation/free paths.

Support is currently limited to host-side fixed-size intrinsic scalar
private and firstprivate variables, including SAVE variables and
individually listed COMMON-block members. Arrays, descriptors, pointers,
allocatables, derived types, named COMMON-block list items, and
target/device allocation remain unsupported.


  Commit: a98dcad4fed01b7d1d2f3a5306a30d658059c431
      https://github.com/llvm/llvm-project/commit/a98dcad4fed01b7d1d2f3a5306a30d658059c431
  Author: Kazu Hirata <kazu at google.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M llvm/include/llvm/ADT/DenseMap.h
    M llvm/utils/LLVMVisualizers/llvm.natvis
    M llvm/utils/gdb-scripts/prettyprinters.py
    M llvm/utils/lldbDataFormatters.py

  Log Message:
  -----------
  [ADT] Extract DenseMapStorage from DenseMap (NFC) (#226664)

This patch extracts the bucket and occupancy storage management from
DenseMap into a new helper class, densemap::detail::DenseMapStorage,
and updates DenseMap to use it via composition.

DenseMapBase::Rep is also moved to densemap::detail::StorageRep so
that DenseMapStorage::getRep() can return it directly.

This is part of the effort to replace CRTP in DenseMapBase with
composition (see #168255).  I'm planning to post a similar patch for
SmallDenseMap before actually removing CRTP.


  Commit: 4564e3842abad0130a6dba143e91307e1336224e
      https://github.com/llvm/llvm-project/commit/4564e3842abad0130a6dba143e91307e1336224e
  Author: Jared Wyles <jared.wyles at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    A orc-rt/lib/bedrock/sys/windows/SocketConnector.cpp
    M orc-rt/tools/ogre/CMakeLists.txt

  Log Message:
  -----------
  [orc-rt] add stub for windows socket support. (#226855)


  Commit: e50507339d91208da79b28f70d4f927828bb7d29
      https://github.com/llvm/llvm-project/commit/e50507339d91208da79b28f70d4f927828bb7d29
  Author: Mend Renovate <bot at renovateapp.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M .github/workflows/bazel-checks.yml
    M .github/workflows/build-ci-container-tooling.yml
    M .github/workflows/build-ci-container-windows.yml
    M .github/workflows/build-ci-container.yml
    M .github/workflows/build-libc-container.yml
    M .github/workflows/build-metrics-container.yml
    M .github/workflows/check-ci.yml
    M .github/workflows/ci-post-commit-analyzer.yml
    M .github/workflows/commit-access-review.yml
    M .github/workflows/compiler-rt-libc-builtins-tests.yml
    M .github/workflows/docs.yml
    M .github/workflows/email-check.yaml
    M .github/workflows/get-llvm-version/action.yml
    M .github/workflows/gha-codeql.yml
    M .github/workflows/hlsl-test-all.yaml
    M .github/workflows/ids-check.yml
    M .github/workflows/issue-release-workflow.yml
    M .github/workflows/issue-write.yml
    M .github/workflows/libc-freebsd-vm-tests.yml
    M .github/workflows/libc-fullbuild-tests.yml
    M .github/workflows/libc-overlay-tests.yml
    M .github/workflows/libc-shared-tests.yml
    M .github/workflows/libclang-abi-tests.yml
    M .github/workflows/libcxx-benchmark-commit.yml
    M .github/workflows/libcxx-benchmark-cron.yml
    M .github/workflows/libcxx-build-containers.yml
    M .github/workflows/libcxx-pr-benchmark.yml
    M .github/workflows/libcxx-pr-check-generated-files.yml
    M .github/workflows/libcxx-pr-conformance-tests.yaml
    M .github/workflows/libcxx-pr-test-tools.yml
    M .github/workflows/lldb-pylint-action.yml
    M .github/workflows/llvm-abi-tests.yml
    M .github/workflows/llvm-bugs.yml
    M .github/workflows/mlir-spirv-tests.yml
    M .github/workflows/new-prs.yml
    M .github/workflows/pr-code-format.yml
    M .github/workflows/pr-code-lint.yml
    M .github/workflows/premerge.yaml
    M .github/workflows/prune-branches.yml
    M .github/workflows/release-asset-audit.yml
    M .github/workflows/release-binaries.yml
    M .github/workflows/release-documentation.yml
    M .github/workflows/release-llvm-testing-tools.yml
    M .github/workflows/release-sources.yml
    M .github/workflows/release-tasks.yml
    M .github/workflows/scorecard.yml
    M .github/workflows/spirv-tests.yml
    M .github/workflows/sycl-tests.yml
    M .github/workflows/test-suite.yml
    M .github/workflows/test-unprivileged-download-artifact.yml
    M .github/workflows/upload-release-artifact/action.yml
    M .github/workflows/version-check.yml
    M .github/workflows/zizmor.yml

  Log Message:
  -----------
  Update [Github] Update GHA Dependencies to v7 (#226858)

This PR contains the following updates:

| Package | Type | Update | Change |
|---|---|---|---|
| [actions/checkout](https://redirect.github.com/actions/checkout) |
action | major | `v6.0.3` → `v7.0.1` |
| [actions/checkout](https://redirect.github.com/actions/checkout) |
action | major | `v6.0.2` → `v7.0.1` |
| [actions/labeler](https://redirect.github.com/actions/labeler) |
action | major | `v6.2.0` → `v7.0.0` |
| [actions/setup-node](https://redirect.github.com/actions/setup-node) |
action | major | `v6.5.0` → `v7.0.0` |
|
[actions/setup-python](https://redirect.github.com/actions/setup-python)
| action | major | f |


  Commit: e7dc4d6436526c4c7b31afec47a47530d98a6801
      https://github.com/llvm/llvm-project/commit/e7dc4d6436526c4c7b31afec47a47530d98a6801
  Author: Pavel Labath <pavel at labath.sk>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M libc/src/__support/OSUtil/linux/syscall_wrappers/close.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/dup.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/dup2.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/dup3.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/fcntl.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/fsync.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/ftruncate.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/lseek.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/memfd_create.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/read.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/write.h

  Log Message:
  -----------
  [libc] Migrate file I/O syscall wrappers to syscall_checked (#226477)

Migrate a batch of related file descriptor and core I/O syscall wrappers
to use syscall_checked instead of manual syscall_impl error checking.

While in there:
- update file headers to the new style
- reformat includes into a single block so clang-format can sort them

Assisted-by: Gemini


  Commit: be628f333947bf070839e6706f6701099e0c83eb
      https://github.com/llvm/llvm-project/commit/be628f333947bf070839e6706f6701099e0c83eb
  Author: Aiden Grossman <aidengrossman at google.com>
  Date:   2026-09-27 (Sun, 27 Sep 2026)

  Changed paths:
    M libcxx/utils/ci/docker/linux-builder.dockerfile

  Log Message:
  -----------
  [libcxx] Still use CMake 3.31 in the CI image (#226749)

This ensures support with the minimum supported version rather than what
26.04 ships with by default (4.2.3).


  Commit: 70f22b8e024924ff69674da78a61da4c200b0e3c
      https://github.com/llvm/llvm-project/commit/70f22b8e024924ff69674da78a61da4c200b0e3c
  Author: Matt Arsenault <Matthew.Arsenault at amd.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/CodeGen/MachineBasicBlock.cpp
    A llvm/test/CodeGen/AMDGPU/phi-elimination-split-critical-edge-subranges.mir

  Log Message:
  -----------
  CodeGen: Fix SplitCriticalEdge using wrong VNInfo for subranges (#226214)

This fixes verifier errors when LiveIntervals is run before phi
elimination.

When extending a live interval across a newly split critical edge for a
PHI source operand, the subrange segments were added using the VNInfo of
the main range instead of the subrange's own value. Look up the
subrange's value at the predecessor's last index, as the other subrange
loop in the same function already does, and skip subranges with no value
there.

Co-authored-by: Claude Opus 5 <noreply at anthropic.com>


  Commit: 7cb518a5a1acf0c2c1df7b5ed207518c45046916
      https://github.com/llvm/llvm-project/commit/7cb518a5a1acf0c2c1df7b5ed207518c45046916
  Author: Matt Arsenault <Matthew.Arsenault at amd.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/include/llvm/CodeGen/AsmPrinter.h
    M llvm/include/llvm/CodeGen/BasicTTIImpl.h
    M llvm/include/llvm/CodeGen/TargetLowering.h
    M llvm/include/llvm/Target/TargetMachine.h
    M llvm/lib/CodeGen/AsmPrinter/AsmPrinter.cpp
    M llvm/lib/CodeGen/CodeGenPrepare.cpp
    M llvm/lib/CodeGen/LiveDebugValues/InstrRefBasedImpl.cpp
    M llvm/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
    M llvm/lib/CodeGen/SelectionDAG/SelectionDAGBuilder.cpp
    M llvm/lib/CodeGen/TargetLoweringBase.cpp
    M llvm/lib/Target/AArch64/AArch64ISelLowering.cpp
    M llvm/lib/Target/AArch64/AArch64TargetMachine.h
    M llvm/lib/Target/AMDGPU/AMDGPULegalizerInfo.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUTargetMachine.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUTargetMachine.h
    M llvm/lib/Target/AMDGPU/SIISelLowering.cpp
    M llvm/lib/Target/AMDGPU/SIISelLowering.h
    M llvm/lib/Target/ARM/ARMInstructionSelector.cpp
    M llvm/lib/Target/ARM/ARMTargetMachine.h
    M llvm/lib/Target/AVR/AVRTargetMachine.h
    M llvm/lib/Target/Hexagon/HexagonTargetMachine.h
    M llvm/lib/Target/LoongArch/LoongArchTargetMachine.h
    M llvm/lib/Target/MSP430/MSP430AsmPrinter.cpp
    M llvm/lib/Target/Mips/MipsTargetMachine.h
    M llvm/lib/Target/NVPTX/NVPTXAsmPrinter.cpp
    M llvm/lib/Target/PowerPC/PPCTargetMachine.h
    M llvm/lib/Target/RISCV/RISCVTargetMachine.cpp
    M llvm/lib/Target/RISCV/RISCVTargetMachine.h
    M llvm/lib/Target/SPIRV/SPIRVSubtarget.cpp
    M llvm/lib/Target/Sparc/SparcISelLowering.cpp
    M llvm/lib/Target/SystemZ/SystemZFrameLowering.cpp
    M llvm/lib/Target/SystemZ/SystemZISelLowering.cpp
    M llvm/lib/Target/SystemZ/SystemZXPLINKAsmPrinter.cpp
    M llvm/lib/Target/VE/VEISelLowering.cpp
    M llvm/lib/Target/X86/GISel/X86LegalizerInfo.cpp
    M llvm/lib/Target/X86/X86ISelLowering.cpp
    M llvm/lib/Target/X86/X86TargetMachine.cpp
    M llvm/lib/Target/X86/X86TargetMachine.h

  Log Message:
  -----------
  TargetMachine: Remove pointer-size query methods (#226404)

Remove the shim methods from the TargetMachine's copy of the DataLayout, 
which will soon be eliminated. The Module owns the authoritative DataLayout, 
so callers should read the value from the contextual Module.

Completely unreasonably, Mips's ABI name can change the pointer size which
we probably should just not support. Many other triple checks will never be 
correct. This avoids potential mismatches in these contexts, but I still expect
this to be widely broken.

Some of the TargetLowering constructor changes and AMDGPULegalizerInfo
changes are kind of annoying. We could pass in the DataLayout through the 
subtarget constructors but it didn't seem worth the effort and the information 
should be derivable from the triple anyway.

Co-authored-by: Claude (Claude-Opus-4.8) <noreply at anthropic.com>


  Commit: ee28ae7685e567d56e9ebb15ac4daf451d43f998
      https://github.com/llvm/llvm-project/commit/ee28ae7685e567d56e9ebb15ac4daf451d43f998
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M orc-rt/tools/ogre/ogre.cpp

  Log Message:
  -----------
  [orc-rt] Add comments to the ogre utility. NFC. (#226900)


  Commit: 55f6f9304fff9a69373d6703d782b8e401d0af86
      https://github.com/llvm/llvm-project/commit/55f6f9304fff9a69373d6703d782b8e401d0af86
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M orc-rt/cmake/OrcRTTesting.cmake
    M orc-rt/test/regression/README.md
    A orc-rt/test/regression/languages/c/addressing/cross-object/global-array-element-pointer-in-data.test
    A orc-rt/test/regression/languages/c/addressing/cross-object/global-data-load.test
    A orc-rt/test/regression/languages/c/addressing/cross-object/hidden-data-load.test
    A orc-rt/test/regression/languages/c/addressing/same-object/global-data-pointer-in-data.c
    A orc-rt/test/regression/languages/c/addressing/same-object/global-data-store.c
    A orc-rt/test/regression/languages/c/addressing/same-object/static-array-element-load.c
    A orc-rt/test/regression/languages/c/addressing/same-object/static-data-load.c
    M orc-rt/test/regression/languages/c/lit.local.cfg
    M orc-rt/test/regression/lit.cfg.py

  Log Message:
  -----------
  [orc-rt] Add initial C addressing regression tests. (#226901)

Add tests that check that JIT'd C code can address data, both in the
same object and in other objects. Each test covers a single construct
(e.g. a load of static data, or a pointer to an array element in another
object stored in initialized data), since linker/loader bugs usually
crash the JIT'd program, and a crash identifies only the failing test.
Each test runs at -O0 and -O2.

To support multi-object tests, add a split-file substitution and lit
feature, and accept .test files in languages/c.

Update the README's test conventions to match: one construct per test,
"Check that" and "Stresses:" header comments, -O0 and -O2 RUN lines, and
guidance on keeping constructs alive under optimization without hiding
the optimized lowering.

Assisted-by: Claude


  Commit: bbbfd872877d184d6a5bd0d2a5322c9fe8387648
      https://github.com/llvm/llvm-project/commit/bbbfd872877d184d6a5bd0d2a5322c9fe8387648
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/docs/ORCv2.md
    M llvm/include/llvm/ExecutionEngine/Orc/Core.h
    M llvm/include/llvm/ExecutionEngine/Orc/ExecutorProcessControl.h
    M llvm/unittests/ExecutionEngine/Orc/ExecutionSessionWrapperFunctionCallsTest.cpp

  Log Message:
  -----------
  [ORC] Remove callSPSWrapper, callSPSWrapperAsync, and callWrapper (#226893)

All in-tree callers now use Proxy. Remove the SPS convenience call
methods from ExecutionSession and ExecutorProcessControl, along with the
unit tests that exercised them (Proxy dispatch is covered by
SPSProxySpecTest). Also remove the blocking callWrapper convenience
methods, which have no remaining users.

Add a "How to call functions in the executor" section to
llvm/docs/ORCv2.md describing Proxy, controller-interface descriptors
and sps::ProxySpec, how lookupAndApply and recordProxy resolve proxies,
and how to migrate from callSPSWrapper.

Clients calling these methods directly should migrate to Proxy; see "How
to call functions in the executor" in llvm/docs/ORCv2.md.


  Commit: 10cd57a6f616dc4836ef572399410d62b16f701d
      https://github.com/llvm/llvm-project/commit/10cd57a6f616dc4836ef572399410d62b16f701d
  Author: Fangrui Song <i at maskray.me>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/include/llvm/CGData/CodeGenData.h
    M llvm/include/llvm/CGData/CodeGenDataReader.h
    M llvm/lib/CGData/CodeGenData.cpp
    M llvm/lib/CGData/CodeGenDataReader.cpp
    M llvm/lib/LTO/LTO.cpp
    M llvm/tools/llvm-cgdata/llvm-cgdata.cpp

  Log Message:
  -----------
  [CGData] Stop exporting cl::opts. NFC (#226861)

LTO reads `-codegen-data-thinlto-two-rounds` through
`extern cl::opt<bool> CodeGenDataThinLTOTwoRounds`, and llvm-cgdata
assigns
`IndexedCodeGenDataLazyLoading`, exported from CodeGenDataReader.h. Add
`cgdata::thinLTOTwoRounds()` for LTO, and pass lazy loading to
`CodeGenDataReader::create` as a parameter, so that the options can be
file-local.

Aided by Opus 5.5


  Commit: 4362da25049882128f50a0f6b4fb69c1a0f8fd57
      https://github.com/llvm/llvm-project/commit/4362da25049882128f50a0f6b4fb69c1a0f8fd57
  Author: Pankaj Dwivedi <pankajkumar.divedi at amd.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Target/AMDGPU/GCNHazardRecognizer.cpp
    M llvm/lib/Target/AMDGPU/GCNHazardRecognizer.h
    M llvm/test/CodeGen/AMDGPU/mai-hazards-gfx90a.mir
    M llvm/test/CodeGen/AMDGPU/mai-hazards-gfx942.mir

  Log Message:
  -----------
  [AMDGPU] Add wait states between different MFMAs sharing an accumulator (#218363)

A full-register src2/C read after an MFMA write emits no wait states,
relying on accumulator forwarding that only works while the chain stays
on one MFMA. Two different MFMAs sharing an accumulator instead need the
wait states of a partial overlap: on gfx950, v_mfma_f32_16x16x32_f16
then
v_mfma_f32_16x16x16_f16 on the same tuple needs 5 and got none. Compare
canonicalized opcodes so mac and register-bank forms still match.

Assisted-by: Claude Opus 5


  Commit: 7a931b5ec3f305a51f702cb0702d2a07f7e74c0b
      https://github.com/llvm/llvm-project/commit/7a931b5ec3f305a51f702cb0702d2a07f7e74c0b
  Author: Kiroo (Chanung) <ung at zlfn.space>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/CodeGen/GlobalISel/LegalizerHelper.cpp

  Log Message:
  -----------
  [GlobalISel] Use getCmpLibcallReturnType() for FCMP libcalls (NFC) (#226813)

The GCC soft-float comparison routines return `CMPtype`, not always
`i32`.


https://gcc.gnu.org/onlinedocs/gccint/Soft-float-library-routines.html#Comparison-functions-1
> 3.2.3 Comparison functions
> There are two sets of basic comparison functions.
> ...
> Runtime Function: CMPtype __unordsf2 (float a, float b)
> Runtime Function: CMPtype __unorddf2 (double a, double b)
> Runtime Function: CMPtype __unordtf2 (long double a, long double b)
> ...

The FCMP libcall result was hardcoded to i32. Use
`getCmpLibcallReturnType()`, as SelectionDAG does.

NFC for in-tree targets.

Co-authored-by: Thorbjørn Ravn Andersen <tra at ravnand.dk>


  Commit: 8fe3fdd6630e04b48dd8253894a8d4ba429e4663
      https://github.com/llvm/llvm-project/commit/8fe3fdd6630e04b48dd8253894a8d4ba429e4663
  Author: Oliver Hunt <oliver at apple.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/IR/Verifier.cpp
    M llvm/lib/Transforms/Utils/CodeExtractor.cpp
    A llvm/test/Assembler/invalid-diexpression-arg-negative.ll
    A llvm/test/DebugInfo/AArch64/dbg-value-arg-index-out-of-range.ll
    A llvm/test/Transforms/HotColdSplit/split-out-dbg-val-arglist.ll
    A llvm/test/Verifier/dbg-record-expression-arg-out-of-range.ll

  Log Message:
  -----------
  [CodeExtractor][Verifier] Fix OoB read when a DIExpression is used multiple times (#226857)

#224360 made fixupDebugInfoPostExtraction reuse the existing
DIExpression, but this is not sound if the expression is referenced
multiple times, as occurs with cold/hot code splitting.

This PR is the trivial fix of restricting this change to only apply if
there is a single user of the expression.

I've also added an additional verifier guard to capture these failures.

Fixes #226848

AI usage: Claude used to find a way to construct
dbg-value-arg-index-out-of-range.ll so that I could add a verifier guard
that bypassed the other existing verifier guards.


  Commit: cb9ee31ad93d35af0ee9172cd368dd537546a8d6
      https://github.com/llvm/llvm-project/commit/cb9ee31ad93d35af0ee9172cd368dd537546a8d6
  Author: jeanPerier <jperier at nvidia.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M flang/include/flang/Optimizer/Transforms/Passes.td
    M flang/lib/Optimizer/Transforms/CMakeLists.txt
    M flang/lib/Optimizer/Transforms/LoopInvariantCodeMotion.cpp
    A flang/test/Transforms/licm-acc-captured-ref.fir
    A flang/test/Transforms/licm-acc-compute-only.fir
    A flang/test/Transforms/licm-scope.fir

  Log Message:
  -----------
  Reland [flang] Support scoped LICM and OpenACC capture provenance (#225401)  (#226909)

Follow compute-region capture operands when checking whether scalar and
scalar-descriptor loads are safe to speculate. Preserve the existing
optional, array-element, and loop-modification safety checks.

Add an optional only-inside operation-name selector while retaining
function-scoped alias analysis. Resolve the name once per function and
compare interned operation names during ancestor traversal. The default
continues to select all loops. An explicit name selects loops with a
matching ancestor within the function, including the function itself.

Cover capture safety, host exclusion, non-OpenACC and nested scopes,
loop boundaries, unmatched names, and the function boundary.

The motivation for this is to allow running LICM only on device relevant
loop at O0.

Reland #225401 with CMakeFiles.txt change to fix shared library builds.


  Commit: 084a4e6002a9b718adb31dd906b233cafd3a9814
      https://github.com/llvm/llvm-project/commit/084a4e6002a9b718adb31dd906b233cafd3a9814
  Author: Steffen Larsen <sholstla at amd.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M clang/lib/CIR/CodeGen/CIRGenBuiltinAMDGPU.cpp
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn-gfx10.hip

  Log Message:
  -----------
  [CIR][AMDGPU] Implement __builtin_amdgcn_*_dpp* builtins (#226469)

This commit implements the `__builtin_amdgcn_update_dpp`,
`__builtin_amdgcn_mov_dpp`, and `__builtin_amdgcn_mov_dpp8` builtins in
CIR, closely matching the implementation in
CodeGenFunction::EmitAMDGPUBuiltinExpr from OGCG.

Assisted-by: Claude Sonnet 5

Signed-off-by: Steffen Holst Larsen <sholstla at amd.com>


  Commit: 44d86afe24ce107f76141ae45f6fe44c44675bbe
      https://github.com/llvm/llvm-project/commit/44d86afe24ce107f76141ae45f6fe44c44675bbe
  Author: Kane Wang <wangqiang1 at kylinos.cn>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/unittests/CodeGen/GlobalISel/LegalizerHelperTest.cpp

  Log Message:
  -----------
  [GlobalISel][NFC] Restore the extended LLT flag to its saved value in tests (#224897)

AArch64GISelMITest's setUp() constructs an AArch64TargetMachine, which
unconditionally enables the process-global extended LLT flag. Ending the
ExtLLT tests with setUseExtended(false) therefore disables the flag for
every test that runs afterwards in the same process.

Save the flag's value on entry and restore it on exit instead.


  Commit: 310cf744bd0c1af7b07377a8fa5a6c2fd72ef4a3
      https://github.com/llvm/llvm-project/commit/310cf744bd0c1af7b07377a8fa5a6c2fd72ef4a3
  Author: Luke Lau <luke at igalia.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/VPlanTransforms.cpp

  Log Message:
  -----------
  [VPlan] Remove (X && Y) | (X && !Y) -> X combine. NFC (#219368)

We have smaller combines that can take care of this now that we process
recipes in a worklist after #213900


  Commit: 6ee306ddac89f9cbfc8815e8956240f0bf832dcb
      https://github.com/llvm/llvm-project/commit/6ee306ddac89f9cbfc8815e8956240f0bf832dcb
  Author: Chris Kennelly <ckennelly at ckennelly.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Target/X86/X86ISelDAGToDAG.cpp
    A llvm/test/CodeGen/X86/bzhi-standalone-mask.ll

  Log Message:
  -----------
  [X86] Select standalone ~(-1 << n) masks as BZHI (#226158)

InstCombine canonicalizes (1 << n) - 1 to xor (shl -1, n), -1. When that
mask feeds an AND, X86DAGToDAGISel::matchBitExtract folds the whole
expression into BZHI, and the add form is selected as BZHI even on its
own because Select enters matchBitExtract from ISD::ADD. The xor form on
its own is not: a mask that is returned, stored, or consumed by anything
but AND is selected as mov -1; shlx; not.

Enter matchBitExtract from ISD::XOR too under BMI2, so the standalone
mask becomes mov -1; bzhi. That is one instruction shorter and avoids
the shlx+not dependency chain. BMI1-only targets keep the shift form,
since BEXTR would need the count moved into bits 15:8 first.

Assisted-by: Claude Code


  Commit: 3804292c4c3adcd4b8505dc78aed73e211b44752
      https://github.com/llvm/llvm-project/commit/3804292c4c3adcd4b8505dc78aed73e211b44752
  Author: David Spickett <david.spickett at arm.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M lldb/unittests/ObjectContainer/ObjectContainerClangOffloadBundleTest.cpp

  Log Message:
  -----------
  [lldb] Fix offload bundle unit tests on 32-bit systems (#226922)

DataExtractor::GetByteSize returns uint64_t for reasons I don't yet
understand. I might change it to size_t but let's unblock the build for
now.

Fixes #222362 / 08ee0ef5da10d27d5776df1e1ff81c46a38d9b5c.


  Commit: 2a96d5737524012839e786699a0b327f22d1cfee
      https://github.com/llvm/llvm-project/commit/2a96d5737524012839e786699a0b327f22d1cfee
  Author: ioana ghiban <ioana.ghiban at arm.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M mlir/include/mlir/Dialect/Utils/StaticValueUtils.h
    M mlir/lib/Dialect/GPU/CMakeLists.txt
    M mlir/lib/Dialect/GPU/Transforms/DecomposeMemRefs.cpp
    M mlir/lib/Dialect/MemRef/IR/MemRefOps.cpp
    M mlir/lib/Dialect/MemRef/Transforms/ExpandStridedMetadata.cpp
    M mlir/lib/Dialect/Utils/StaticValueUtils.cpp
    M mlir/lib/IR/BuiltinTypes.cpp
    M mlir/test/Conversion/MemRefToSPIRV/memref-to-spirv.mlir
    M mlir/test/Dialect/GPU/decompose-memrefs.mlir
    M mlir/test/Dialect/MemRef/canonicalize.mlir
    M mlir/test/Dialect/MemRef/elide-reinterpret-cast-load.mlir
    M mlir/test/Dialect/MemRef/expand-strided-metadata.mlir
    M mlir/test/Dialect/MemRef/ops.mlir

  Log Message:
  -----------
  [mlir][memref] Enforce consistent reinterpret_cast metadata (#217338)

This PR implements [[RFC] Clarify `memref.reinterpret_cast` Verification
of Dynamic
Metadata](https://discourse.llvm.org/t/rfc-clarify-memref-reinterpret-cast-verification-of-dynamic-metadata).

## Context
`memref.reinterpret_cast` describes its result through both its mixed
offset/size/stride metadata and its result `MemRefType`. Currently,
verification allowed a dynamic result-type correspond to static
operation metadata, introducing inconsistent descriptors.

For example, the verifier permits:
```mlir
%r = memref.reinterpret_cast %base
    to offset: [0], sizes: [%n, 2], strides: [%s, 1] : memref<f32>
      to memref<?x?xf32, strided<[?, ?], offset: ?>>
```
where the operation constructs a descriptor with a statically known
second size and stride, but the result type does not expose those facts.

## Changes
This PR consolidates the verifier to require `reinterpret_cast` result
type’s sizes, offset, and strides to exactly match the static/dynamic
representation and values of the operation metadata.

Transforms that create `memref.reinterpret_cast`, including GPU memref
decomposition and strided-metadata expansion for `subview` and
`collapse_shape`, now derive the result type from the final, potentially
folded descriptor instead of inheriting the original operation’s result
type.

When this descriptor-derived type differs from the original result type,
the rewrite inserts a `memref.cast` back to the original type. These
rewrites are not type-conversion patterns, so their existing
users—including function returns and calls—must retain their original
types. Identity stride layouts are canonicalized when possible to avoid
unnecessary explicit layouts and casts.

Tests are updated to use result types consistent with their
`reinterpret_cast` metadata. In the SPIR-V tests, the size `10` is
represented by an SSA value because those cases intentionally remain
dynamically shaped and lower to element pointers; making the size static
would change the SPIR-V pointee type and prevent the existing
`reinterpret_cast` lowering from applying.

A regression test also verifies that folded `subview` offsets and
strides are reflected in the generated `reinterpret_cast` type.

---
Assisted-by: Codex (refine implementation + tests). I reviewed all code
and tests before submission.


  Commit: fe5ace607b587df1d46174846c40e3afe2c0a4a3
      https://github.com/llvm/llvm-project/commit/fe5ace607b587df1d46174846c40e3afe2c0a4a3
  Author: Yuvaraj Venkatesh <yuvaraj.venkatesh at arm.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M mlir/include/mlir/Dialect/Tosa/IR/TosaOps.td
    M mlir/test/Conversion/TosaToSPIRVTosa/graph-constant-mark.mlir
    M mlir/test/Dialect/Tosa/canonicalize.mlir
    M mlir/test/Dialect/Tosa/constant_folding.mlir
    M mlir/test/Dialect/Tosa/ops.mlir
    M mlir/test/Dialect/Tosa/tosa-arith-const-to-tosa-const.mlir
    M mlir/test/Dialect/Tosa/tosa-convert-integer-type-to-signless.mlir
    M mlir/test/Dialect/Tosa/tosa-decompose-depthwise.mlir
    M mlir/test/Dialect/Tosa/tosa-decompose-transpose-conv.mlir
    M mlir/test/Dialect/Tosa/tosa-gather-scatter-hardening.mlir
    M mlir/test/Dialect/Tosa/tosa-infer-shapes.mlir
    M mlir/test/Dialect/Tosa/tosa-layerwise-constant-fold-dense-resource.mlir
    M mlir/test/Dialect/Tosa/tosa-layerwise-constant-fold.mlir
    M mlir/test/Dialect/Tosa/tosa-narrow-f32-to-f16-aggressive.mlir
    M mlir/test/Dialect/Tosa/tosa-narrow-f32-to-f16.mlir
    M mlir/test/Dialect/Tosa/tosa-narrow-f64-to-f32-aggressive.mlir
    M mlir/test/Dialect/Tosa/tosa-narrow-f64-to-f32.mlir
    M mlir/test/Dialect/Tosa/tosa-narrow-i64-to-i32-aggressive.mlir
    M mlir/test/Dialect/Tosa/tosa-narrow-i64-to-i32.mlir
    M mlir/test/Dialect/Tosa/tosa-reduce-transposes.mlir

  Log Message:
  -----------
  [mlir][tosa] Add assembly format for CONST (#226147)

This commit adds an assembly format for the TOSA CONST operation.
Previously, the generic assembly format was used while all other
operations had a custom format. It takes advantage of the incoming
textual format changes in #217291, to minimise impact to downstream
consumers.


  Commit: 9fdcf6a0cafba6af912da2acb58f19addeb7722c
      https://github.com/llvm/llvm-project/commit/9fdcf6a0cafba6af912da2acb58f19addeb7722c
  Author: Momchil Velikov <momchil.velikov at arm.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/include/llvm/Transforms/Scalar/GVN.h
    M llvm/lib/Transforms/Scalar/GVN.cpp

  Log Message:
  -----------
  [GVN] Decouple GVNValueTable and GVNPass (NFC) (#226232)

This is a first patch in series with the ultimate goal to move `GVNPass`
out of `GVN.h` and into `GVN.cpp`.

This is not straightforward because because of the rather tangled
dependencies between `GVNPass`, `GVNHoistPass`, `ValueTable`, and
`LeaderMap`.

The `GVNHoistPass` pass references `GVNPass::ValueTable`, by peeking
into `GVNPass`, resp. including `GVN.h`. Since `GVNHoistPass` does not
actually depend on `GVNPass` itself, but only on the `ValueTable` it
contains, it would make more sense to move `ValueTable` out of `GVN.h`
to its own header file, to be included by both `GVN.h` and
`GVNHoist.cpp.`

That's not entirely straightforward either since `ValueTable` has
several member functions taking a `GVNPass` reference as an argument.
This prevents moving `GVNPass` out of `GVN.h` and into an anonymous
namespace in `GVN.cpp`.

These `GVNPass` (in `ValueTable`) references are only used to access the
`LeaderMap`. Consequently, `LeaderMap` can be moved out of `GVNPass` and
into the `llvm` namespace and forward declared for its uses by
`ValueTable` (when `ValueTable` gets its own header).

This patch moves the `LeaderMap` out of `GVNPass`, into the `llvm`
namespace, and renames it to `GVNLeaderMap`.


  Commit: be2eb0a91356ae3a1910d8226137b54db480166d
      https://github.com/llvm/llvm-project/commit/be2eb0a91356ae3a1910d8226137b54db480166d
  Author: Mariusz Sikora <mariusz.sikora at amd.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Target/AMDGPU/AMDGPU.td
    M llvm/lib/Target/AMDGPU/SIInstrInfo.td
    M llvm/lib/Target/AMDGPU/VOP3Instructions.td
    M llvm/test/MC/AMDGPU/gfx13_asm_vop3-fake16.s
    M llvm/test/MC/AMDGPU/gfx13_asm_vop3.s
    A llvm/test/MC/AMDGPU/gfx13_asm_vop3_from_vop1_err-fake16.s
    A llvm/test/MC/AMDGPU/gfx13_asm_vop3_from_vop1_err.s

  Log Message:
  -----------
  [AMDGPU] Add gfx13 MC support for exclusive scan instructions (#226077)


  Commit: f1de563a490b486738e65a6fef040e0e40d1bb21
      https://github.com/llvm/llvm-project/commit/f1de563a490b486738e65a6fef040e0e40d1bb21
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/test/Transforms/SLPVectorizer/X86/runtime-alias-checks.ll

  Log Message:
  -----------
  [SLP][NFC]Add a test with the missing runtime checks for vectorization, NFC



Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/226947


  Commit: 4c31d2c7641e180c2c9098e466b2247bb470fc25
      https://github.com/llvm/llvm-project/commit/4c31d2c7641e180c2c9098e466b2247bb470fc25
  Author: Matt Arsenault <Matthew.Arsenault at amd.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    A llvm/test/CodeGen/AMDGPU/rewrite-vgpr-mfma-to-agpr-spill-multi-store-codegen.ll
    M llvm/test/CodeGen/AMDGPU/rewrite-vgpr-mfma-to-agpr-spill-multi-store.ll

  Log Message:
  -----------
  AMDGPU: Make rewrite-vgpr-mfma-to-agpr-spill-multi-store.ll less allocator sensitive (#226913)

This test is sensitive to the exact split and spills which occur, and disappeared  under 
a future upstream improvement. Use basic RA with a fixed occupancy since it more
stably produces the spill pattern.

Also add a codegen reference test for the same kernel, so future codegen
improvements are visible.

Co-authored-by: Claude Opus 5 <noreply at anthropic.com>


  Commit: c44450f30d17c64005fc74c506a01c373ddf702c
      https://github.com/llvm/llvm-project/commit/c44450f30d17c64005fc74c506a01c373ddf702c
  Author: Weiwen He <60433849+he-weiwen at users.noreply.github.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Target/X86/X86ISelLowering.cpp
    M llvm/test/CodeGen/X86/cmp-shiftX-maskX.ll
    A llvm/test/CodeGen/X86/cmp-shrink-unsigned.ll

  Log Message:
  -----------
  [X86] Shrink i32 unsigned compares to i8/i16 when high bits are zero (#197801)

Shrink i32 compares to 8 or 16 bit for non-constant operands when high
bits are zero, following the precedent of i64 -> i32 case.

Fixes the cases in #196827 where both sides of the compare are
non-constants, as this allows the `and(X, mask) `to be eliminated
downstream in DAGCombine.

I believe we can extend to constant operands as long as the length
changing prefix problem for i16 immediates is accounted for - however:
1. it's not sufficient to fix the remaining cases in the motivating
issue alone: when the rhs is constant, InstCombine clear the bits in the
mask that does not affect the comparison result (`icmp (and X, 255),
123` -> `icmp (and X, 252), 123`), so the mask does not fill the full
width of the truncated type, making the analysis trickier.
2. it leads to a lot of check line drifts, i'm not sure if it's worth
the effort to account for all of them, even if most don't look like
regressions.


  Commit: a945adae2eb9236392fbbfe1ab5181f8c073d6f8
      https://github.com/llvm/llvm-project/commit/a945adae2eb9236392fbbfe1ab5181f8c073d6f8
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Analysis/ScalarEvolution.cpp

  Log Message:
  -----------
  [SCEV] Use makeExactNoWrapRegion for constant operands. (NFC) (#223973)

Use makeExactNoWrapRegion when constant is available.

Together with https://github.com/llvm/llvm-project/pull/223969, this
reduces compile-time in SCEV heavy workloads:

stage1-O3: -0.10%
stage1-ReleaseThinLTO: -0.0.9%
stage1-ReleaseLTO-g: -0.08%
stage1-aarch64-O3: -0.09%
stage2-O3: -0.07%

https://llvm-compile-time-tracker.com/compare.php?from=016fa12d18058b83c528f2af859e45df4548034f&to=e2efeaf6a19ac8c53170f2a2b196f3d38268fd32&stat=instructions:u

PR: https://github.com/llvm/llvm-project/pull/223973


  Commit: 7f133e72828d68cbd8ce06bf64ea0fe8b8528c06
      https://github.com/llvm/llvm-project/commit/7f133e72828d68cbd8ce06bf64ea0fe8b8528c06
  Author: Nikita Popov <npopov at redhat.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/include/llvm/AsmParser/LLParser.h
    M llvm/lib/AsmParser/LLParser.cpp
    M llvm/test/Bitcode/upgrade-tbaa.ll
    A llvm/test/Bitcode/upgrade-tbaa.ll.bc
    M polly/test/CodeGen/OpenMP/single_loop_with_loop_invariant_baseptr.ll

  Log Message:
  -----------
  [AsmParser] Remove TBAA auto-upgrade in IR parser (#226914)

At this point, the struct path TBAA format is more than a decade old, so
remove support for upgrading from the old format in the textual IR
parser. Bitcode upgrade support is retained, as bitcode is backwards
compatible.

This avoids introduction of new tests using the old format. Existing
tests were migrated in https://github.com/llvm/llvm-project/pull/226051.


  Commit: 82aa78850bb1c90df3d747062555b2f34b0466c5
      https://github.com/llvm/llvm-project/commit/82aa78850bb1c90df3d747062555b2f34b0466c5
  Author: Ramkumar Ramachandra <artagnon at tenstorrent.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/include/llvm/Analysis/ScalarEvolution.h
    M llvm/lib/Analysis/ScalarEvolution.cpp

  Log Message:
  -----------
  [SCEV] Rename SCEVFlags -> SCEVFlagsPair (NFC) (#226935)

Make it clear that it's a pair of no-wrap flags, and free up the
SCEVFlags name for renaming SCEVNoWrapFlags to it.


  Commit: c786529445a1ecb3e8618eba4d68132e40c2e40f
      https://github.com/llvm/llvm-project/commit/c786529445a1ecb3e8618eba4d68132e40c2e40f
  Author: Mian Miftah <mmiftah.duna at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Utils/SimplifyCFG.cpp
    M llvm/test/Transforms/SimplifyCFG/hoist-common-skip.ll

  Log Message:
  -----------
  [SimplifyCFG] Drop UB-implying attributes when hoisting speculatively (#226746)

`hoistCommonCodeFromSuccessors()` can hoist identical instructions past
non-identical ones that it skips. If a skipped instruction may throw or
not return, the hoisted instruction is speculated, but it keeps its
UB-implying attributes and metadata, like `noundef`. Drop them in that
case, as SimplifyCFG already does when it speculates.


  Commit: bc4c516f6e324d147eaeea1bd7d58eb57d03a671
      https://github.com/llvm/llvm-project/commit/bc4c516f6e324d147eaeea1bd7d58eb57d03a671
  Author: David Spickett <david.spickett at arm.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M lldb/test/API/functionalities/scripted_frame_provider/thread_filter/TestFrameProviderThreadFilter.py

  Log Message:
  -----------
  [lldb][test] Enable TestFrameProviderThreadFilter.py on Arm (#226953)

Fixes #191855. I do not know why, but this test no longer crashes on
Arm.


  Commit: 17b078d0b68d8d081e5add811b0d6cd91b374160
      https://github.com/llvm/llvm-project/commit/17b078d0b68d8d081e5add811b0d6cd91b374160
  Author: Tomas Matheson <Tomas.Matheson at arm.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Utils/BuildLibCalls.cpp
    M llvm/test/Transforms/InferFunctionAttrs/annotate.ll

  Log Message:
  -----------
  [BuildLibCalls] Infer attributes for posix_memalign (#226943)

Handle posix_memalign in inferNonMandatoryLibFuncAttrs.


  Commit: 3123f219c9a536a586df1d253d13ec49ab95ca38
      https://github.com/llvm/llvm-project/commit/3123f219c9a536a586df1d253d13ec49ab95ca38
  Author: Mian Miftah <mmiftah.duna at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/IPO/MergeFunctions.cpp
    A llvm/test/Transforms/MergeFunc/redirect-call-debug-loc.ll

  Log Message:
  -----------
  [MergeFunctions] Add debug locations to redirected calls (#225625)

A call to a function without debug info does not need a debug location,
even in a function with debug info. If MergeFunctions redirects such a
call to an equivalent function that has debug info, the verifier fails:

```
inlinable function call in a function with debug info must have a !dbg location
```

Before redirecting such a call, give it a line 0 location in the scope
of the caller, as `DwarfEHPrepare` does for the call to the rewind
function. This covers both ways calls are redirected:
`replaceDirectCallers()`, and `replaceAllUsesWith()` for `unnamed_addr`
functions.


  Commit: 380d489bcd2a4e4dbe877f9518ee696348f419ea
      https://github.com/llvm/llvm-project/commit/380d489bcd2a4e4dbe877f9518ee696348f419ea
  Author: David Spickett <david.spickett at arm.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M lldb/test/API/api/multiple-debuggers/multi-process-driver.cpp

  Log Message:
  -----------
  [lldb][test] Fix undefined behaviour in multi process driver (#226949)

This code was using strcmp on function names. Function names can be null
(see SBFrame::GetFunctionName), and passing null to strcmp is UB.


  Commit: ccd2a3f748d7a4898fe2850491796f01603e8d72
      https://github.com/llvm/llvm-project/commit/ccd2a3f748d7a4898fe2850491796f01603e8d72
  Author: Dávid Bolvanský <david.bolvansky at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Analysis/BasicAliasAnalysis.cpp

  Log Message:
  -----------
  [BasicAA] Compute minimal access extents lazily (#226931)

`aliasCheck` computes the minimal extent of an access before calling
`isObjectSmallerThan`, even though the latter immediately returns false
when the other pointer is not an identified object.

Move the extent computation behind the existing `isIdentifiedObject`
check. This preserves the result: whenever the extent can affect the
answer, the same value is computed and used as before; otherwise only
unused work is skipped.


  Commit: 4df13761d078a2f3c10c4ed7fab033df116b6cdc
      https://github.com/llvm/llvm-project/commit/4df13761d078a2f3c10c4ed7fab033df116b6cdc
  Author: Tim Besard <tim.besard at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    A llvm/test/Transforms/SLPVectorizer/X86/strength-reducible-address.ll

  Log Message:
  -----------
  [SLP] Add tests for affine loop address computations (NFC) (#226907)

Precommit tests for #226220: related affine address recurrences in a
loop whose index arithmetic SLP currently vectorizes and extracts per
lane for scalar loads and stores, which LSR would otherwise turn into
pointer increments.

`X86/strength-reducible-address.ll` has Haswell and skylake-avx512 RUN
lines. It covers strided loads, constant-offset GEPs, and a load/store
at the same address. The negative cases are loop-loaded offsets,
escaping addresses, and offsets computed in the preheader. The checks
are generated with current main.


  Commit: eac59201583b098cbd6b4b4619d165e90f50937d
      https://github.com/llvm/llvm-project/commit/eac59201583b098cbd6b4b4619d165e90f50937d
  Author: Vikash Gupta <Vikash.Gupta at amd.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/CodeGen/GlobalISel/GISelValueTracking.cpp
    A llvm/test/CodeGen/AArch64/GlobalISel/knownbits-freeze.mir
    M llvm/test/CodeGen/AArch64/GlobalISel/knownfpclass-ops.mir

  Log Message:
  -----------
  [GlobalISel] Support GISelValueTracking for G_FREEZE. (#223696)

Port the SDAG FREEZE handling to GlobalISel. Look through G_FREEZE in
computeKnownBits, computeNumSignBits, and computeKnownFPClass when the
source is guaranteed not undef or poison.

Part of #150515.

---------

Co-authored-by: Matt Arsenault <arsenm2 at gmail.com>


  Commit: 71cbaace075d39f87063afa9d0da165ee04345b3
      https://github.com/llvm/llvm-project/commit/71cbaace075d39f87063afa9d0da165ee04345b3
  Author: David Green <david.green at arm.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Target/AArch64/AArch64ISelLowering.cpp
    M llvm/test/CodeGen/AArch64/binopshuffles.ll
    M llvm/test/CodeGen/AArch64/fp-intrinsics-vector.ll
    M llvm/test/CodeGen/AArch64/neon-truncstore.ll
    M llvm/test/CodeGen/AArch64/store.ll
    M llvm/test/CodeGen/AArch64/sve-extract-vector-to-predicate-store.ll
    M llvm/test/CodeGen/AArch64/vec3-loads-ext-trunc-stores.ll

  Log Message:
  -----------
  [AArch64] Combine truncate(buildvector) -> buildvector (#223787)

If late in the pipeline we are left with truncate(buildvector), we can
generate the buildvector directly. This helps remove the xtn and can
lead to other simplification.


  Commit: ca1b270af6e567ae7caa50cd2b3ede418b7cde5f
      https://github.com/llvm/llvm-project/commit/ca1b270af6e567ae7caa50cd2b3ede418b7cde5f
  Author: Abhina Sree <Abhina.Sreeskantharajan at ibm.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M clang/tools/clang-ssaf-src-edit-merge/SrcEditMerge.cpp

  Log Message:
  -----------
  [SystemZ][z/OS] Open text files as text (#226518)

This patch fixes lit regressions in clang-ssaf-src-edit-merge by opening
text files as text.


  Commit: 6861b01646bd770523e94f3efe572f598cfdcc53
      https://github.com/llvm/llvm-project/commit/6861b01646bd770523e94f3efe572f598cfdcc53
  Author: Igor Wodiany <igor.wodiany at amd.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/ObjectYAML/DWARFEmitter.cpp

  Log Message:
  -----------
  [DWARFYAML] Declare `OffsetEntryCount` as `uint64_t` (#224631)

This prevents a potential multiplication overflow when `OffsetsSize` is
calculated and fixes an issue reported by a CodeQL scan.


  Commit: 141ad3d5e3312eccc977b20af18c978e46fd9b40
      https://github.com/llvm/llvm-project/commit/141ad3d5e3312eccc977b20af18c978e46fd9b40
  Author: Dhairyashil R G <dhairyashil25 at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M mlir/include/mlir/Dialect/LLVMIR/NVVMOps.td
    M mlir/test/Dialect/LLVMIR/nvvm_check_target_sm.mlir

  Log Message:
  -----------
  [MLIR][NVVM] Add SM version requirements to mbarrier Ops (#224105)

The mbarrier Ops had no `NVVMRequiresSM` trait, so a `gpu.module`
targeting an older chip (e.g. `sm_75`) accepted them, and the error only
showed up later. This adds the trait to all 13 of them, same as #192257
and `mbarrier.check_layout` in #217252.

| floor | Ops |
|---|---|
| `sm_80` | `init`, `inval`, `arrive`, `arrive_drop`,
`arrive.nocomplete`, `arrive_drop.nocomplete`, `test.wait` |
| `sm_90` | `expect_tx`, `complete_tx`, `arrive.expect_tx`,
`arrive_drop.expect_tx`, `try_wait`, `try_wait.parity` |

The floors come from the Target ISA Notes in the [PTX ISA
8.5](https://docs.nvidia.com/cuda/pdf/ptx_isa_8.5.pdf) (section
9.7.12.15), and they match the backend: every Op that lowers to an
intrinsic fails to compile one arch below its floor and compiles at it.
`arrive_drop` at sm_80 relies on #222916.

Since the trait is per Op, some settings that need sm_90 still get
through on sm_80: an explicit `count`, `scope = cluster`, a
`shared::cluster` pointer, `relaxed = true`, or `layout` on `init`.
Catching those would mean the Ops implementing `getRequiredMinSMVersion`
themselves, which no Op does yet. Happy to add that if you'd like. PTX
version isn't covered either (#69448).

One behaviour change: `gpu-lower-to-nvvm-pipeline` and
`nvvm-attach-target` default to `sm_75`, so using mbarrier Ops with that
default now fails earlier, with a clear message. `verifyTarget = false`
turns the check off.

Tests are in `nvvm_check_target_sm.mlir`: one failing case per Op just
below its floor, plus passing cases at the floor, above it, and on
`sm_90a`.

Assisted-by: Claude


  Commit: 3eb90f564e8b3c8bc93c1f139589ebad30f09b9e
      https://github.com/llvm/llvm-project/commit/3eb90f564e8b3c8bc93c1f139589ebad30f09b9e
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/VPlan.h
    M llvm/lib/Transforms/Vectorize/VPlanRecipes.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUtils.cpp
    M llvm/test/Transforms/LoopVectorize/VPlan/execution-frequencies-match-bfi.ll
    M llvm/test/Transforms/LoopVectorize/X86/predicated-instruction-cost.ll
    M llvm/test/Transforms/LoopVectorize/replicate-region-branch-weights.ll

  Log Message:
  -----------
  [VPlan] Distribute execution frequencies with BlockFrequencyInfo's code. (#226841)

Instead of hand-rolling frequency propagating, manually construct BFI
and use BFI::distributeMass.

Adds a final step where frequencies are rounded up to at least one, to
distinguish between unreachable and almost never executed blocks. This
matches BFI behavior.

Note that we need to still track whether frequencies are from edges with
unknown profile info.

PR: https://github.com/llvm/llvm-project/pull/226841


  Commit: d8b7da91eb8d8c2232c58a9f8b9f2136861da343
      https://github.com/llvm/llvm-project/commit/d8b7da91eb8d8c2232c58a9f8b9f2136861da343
  Author: Will Hawkins <hawkinsw at obs.cr>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/include/llvm-c/DebugInfo.h
    M llvm/include/llvm/BinaryFormat/Dwarf.def
    M llvm/include/llvm/BinaryFormat/Dwarf.h
    M llvm/lib/BinaryFormat/Dwarf.cpp
    A llvm/test/DebugInfo/Generic/compileunit-source-language-name-roc.ll

  Log Message:
  -----------
  [DWARF] Support Roc Language (#225631)

The Roc language has been assigned language codes for DWARF v5 and v6.
See [DWARF Issue 260821.1](https://dwarfstd.org/issues/260828.1.html).


  Commit: cf5a39d92984abb7e6e2bac57af6dd9c0abba21a
      https://github.com/llvm/llvm-project/commit/cf5a39d92984abb7e6e2bac57af6dd9c0abba21a
  Author: Krzysztof Parzyszek <Krzysztof.Parzyszek at amd.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Frontend/OpenMP/OMPDescriptors.inc

  Log Message:
  -----------
  [OpenMP] Add/update descriptors for extension clauses (#226509)


  Commit: 5d8b5942fa5924d1bf1920fe63623d8e50c58d9a
      https://github.com/llvm/llvm-project/commit/5d8b5942fa5924d1bf1920fe63623d8e50c58d9a
  Author: Krzysztof Parzyszek <Krzysztof.Parzyszek at amd.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M llvm/lib/Frontend/OpenMP/OMPDescriptors.inc

  Log Message:
  -----------
  [OpenMP] Update modifier set properties on some clauses (#226508)

The modifier sets on DEPEND, NUM_TEAMS and REDUCTION in 6.1 only have
the exclusive property.


  Commit: 8af4ce85a25634994ebd19223dac15213b1a7dbc
      https://github.com/llvm/llvm-project/commit/8af4ce85a25634994ebd19223dac15213b1a7dbc
  Author: Mehdi Amini <joker.eph at gmail.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M clang/include/clang/CIR/Dialect/IR/CIRAttrs.td
    M clang/include/clang/CIR/Dialect/IR/CIRDialect.td
    M clang/include/clang/CIR/Dialect/IR/CIROps.td
    M clang/lib/CIR/CodeGen/CIRGenExprCXX.cpp
    M clang/lib/CIR/Dialect/Transforms/CXXABILowering.cpp
    M clang/test/CIR/Analysis/alias-analysis-modref.cir
    M clang/test/CIR/Analysis/alias-analysis-underlying-object.cir
    M clang/test/CIR/CodeGen/alignment.c
    M clang/test/CIR/CodeGen/atomic.c
    M clang/test/CIR/CodeGen/bitint-memory.c
    M clang/test/CIR/CodeGen/bitint-record-layout.c
    M clang/test/CIR/CodeGen/bitint-wide-be.c
    M clang/test/CIR/CodeGen/bitint-wide.c
    M clang/test/CIR/CodeGen/bitint.c
    M clang/test/CIR/CodeGen/builtin-call.cpp
    M clang/test/CIR/CodeGen/compound_literal.c
    M clang/test/CIR/CodeGen/delete-array-aligned.cpp
    M clang/test/CIR/CodeGen/delete-array-overaligned-cookie.cpp
    M clang/test/CIR/CodeGen/delete-array-throwing-dtor.cpp
    M clang/test/CIR/CodeGen/delete-array-unsized-dtor.cpp
    M clang/test/CIR/CodeGen/delete-array.cpp
    M clang/test/CIR/CodeGen/empty-union.cpp
    M clang/test/CIR/CodeGen/fixed-point-literal.c
    M clang/test/CIR/CodeGen/fp-contract.c
    M clang/test/CIR/CodeGen/global-const-alignment.cpp
    M clang/test/CIR/CodeGen/global-init-fenv.cpp
    M clang/test/CIR/CodeGen/global-section.c
    M clang/test/CIR/CodeGen/global-tls-dyn-init.cpp
    M clang/test/CIR/CodeGen/globals.cpp
    M clang/test/CIR/CodeGen/lambda.cpp
    M clang/test/CIR/CodeGen/local-const-aggregate-name-clash.cpp
    M clang/test/CIR/CodeGen/no-odr-use.cpp
    M clang/test/CIR/CodeGen/non-odr-use-non-ref.cpp
    M clang/test/CIR/CodeGen/nonzeroinit-struct.cpp
    M clang/test/CIR/CodeGen/paren-list-agg-init.cpp
    M clang/test/CIR/CodeGen/pointer-to-data-member-indirect-field.cpp
    M clang/test/CIR/CodeGen/pointer-width-32bit.cpp
    M clang/test/CIR/CodeGen/pragma-fenv_access.c
    M clang/test/CIR/CodeGen/predefined-expr.c
    M clang/test/CIR/CodeGen/source-loc.cpp
    M clang/test/CIR/CodeGen/static-local-in-ctor.cpp
    M clang/test/CIR/CodeGen/static-local-info.cpp
    M clang/test/CIR/CodeGen/tls-model.cpp
    M clang/test/CIR/CodeGen/union-agg-init.c
    M clang/test/CIR/CodeGen/vbase.cpp
    M clang/test/CIR/CodeGen/vector-strict-fp.cpp
    M clang/test/CIR/CodeGen/vtt.cpp
    M clang/test/CIR/CodeGenCUDA/address-spaces.cu
    M clang/test/CIR/CodeGenCUDA/device-stub.cu
    M clang/test/CIR/CodeGenCUDA/kernel-call.cu
    M clang/test/CIR/CodeGenCXX/global-refs.cpp
    M clang/test/CIR/CodeGenCXX/init-priority-attr.cpp
    M clang/test/CIR/CodeGenCXX/vtable-linkage.cpp
    M clang/test/CIR/CodeGenCXX/zero_init_bases.cpp
    M clang/test/CIR/IR/attribute-visibility.cir
    M clang/test/CIR/IR/fenv.cir
    M clang/test/CIR/IR/global.cir
    M clang/test/CIR/IR/invalid-cast.cir
    M clang/test/CIR/IR/invalid-cmp.cir
    M clang/test/CIR/IR/invalid-delete-array.cir
    M clang/test/CIR/IR/invalid-static-local-info.cir
    M clang/test/CIR/IR/invalid-static-local.cir
    M clang/test/CIR/IR/invalid-tls.cir
    M clang/test/CIR/IR/invalid-vtable.cir
    M clang/test/CIR/IR/static-local-info.cir
    M clang/test/CIR/IR/static-local.cir
    M clang/test/CIR/IR/string-trailing-zeros.cir
    M clang/test/CIR/IR/var-registration.cir
    M clang/test/CIR/IR/vtable-addrpt.cir
    M clang/test/CIR/IR/vtable-attr.cir
    M clang/test/CIR/IR/vtt-addrpoint.cir
    M clang/test/CIR/Lowering/call-llvm-intrinsic.cir
    M clang/test/CIR/Lowering/fenv.cir
    M clang/test/CIR/Lowering/vtt-addrpoint.cir
    M clang/test/CIR/Transforms/vector-cmp-fold.cir
    M clang/unittests/CIR/FenvOpTest.cpp

  Log Message:
  -----------
  Make CIR assembly formats strict properties compatible (#226600)

Bind inherent attributes explicitly in CIR operation formats and update
assembly tests for the resulting syntax.

Assisted-by: Codex


  Commit: bafd66d3318928a31802218852c863c3a1abe687
      https://github.com/llvm/llvm-project/commit/bafd66d3318928a31802218852c863c3a1abe687
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-09-28 (Mon, 28 Sep 2026)

  Changed paths:
    M .github/workflows/bazel-checks.yml
    M .github/workflows/build-ci-container-tooling.yml
    M .github/workflows/build-ci-container-windows.yml
    M .github/workflows/build-ci-container.yml
    M .github/workflows/build-libc-container.yml
    M .github/workflows/build-metrics-container.yml
    M .github/workflows/check-ci.yml
    M .github/workflows/ci-post-commit-analyzer.yml
    M .github/workflows/commit-access-review.yml
    M .github/workflows/compiler-rt-libc-builtins-tests.yml
    M .github/workflows/docs.yml
    M .github/workflows/email-check.yaml
    M .github/workflows/get-llvm-version/action.yml
    M .github/workflows/gha-codeql.yml
    M .github/workflows/hlsl-test-all.yaml
    M .github/workflows/ids-check.yml
    M .github/workflows/issue-release-workflow.yml
    M .github/workflows/issue-write.yml
    M .github/workflows/libc-freebsd-vm-tests.yml
    M .github/workflows/libc-fullbuild-tests.yml
    M .github/workflows/libc-overlay-tests.yml
    M .github/workflows/libc-shared-tests.yml
    M .github/workflows/libclang-abi-tests.yml
    M .github/workflows/libcxx-benchmark-commit.yml
    M .github/workflows/libcxx-benchmark-cron.yml
    M .github/workflows/libcxx-build-containers.yml
    M .github/workflows/libcxx-pr-benchmark.yml
    M .github/workflows/libcxx-pr-check-generated-files.yml
    M .github/workflows/libcxx-pr-conformance-tests.yaml
    M .github/workflows/libcxx-pr-test-tools.yml
    M .github/workflows/lldb-pylint-action.yml
    M .github/workflows/llvm-abi-tests.yml
    M .github/workflows/llvm-bugs.yml
    M .github/workflows/mlir-spirv-tests.yml
    M .github/workflows/new-prs.yml
    M .github/workflows/pr-code-format.yml
    M .github/workflows/pr-code-lint.yml
    M .github/workflows/premerge.yaml
    M .github/workflows/prune-branches.yml
    M .github/workflows/release-asset-audit.yml
    M .github/workflows/release-binaries.yml
    M .github/workflows/release-documentation.yml
    M .github/workflows/release-llvm-testing-tools.yml
    M .github/workflows/release-sources.yml
    M .github/workflows/release-tasks.yml
    M .github/workflows/scorecard.yml
    M .github/workflows/spirv-tests.yml
    M .github/workflows/sycl-tests.yml
    M .github/workflows/test-suite.yml
    M .github/workflows/test-unprivileged-download-artifact.yml
    M .github/workflows/upload-release-artifact/action.yml
    M .github/workflows/version-check.yml
    M .github/workflows/zizmor.yml
    M bolt/docs/conf.py
    M clang-tools-extra/clang-tidy/bugprone/RedundantBranchConditionCheck.cpp
    M clang-tools-extra/docs/ReleaseNotes.md
    M clang-tools-extra/test/clang-tidy/checkers/bugprone/redundant-branch-condition.cpp
    M clang/docs/AllocToken.md
    M clang/docs/ClangLinkerWrapper.md
    M clang/docs/ClangOffloadBundler.md
    M clang/docs/ClangTransformerTutorial.md
    M clang/docs/ControlFlowIntegrity.md
    M clang/docs/ControlFlowIntegrityDesign.md
    M clang/docs/InternalsManual.md
    M clang/docs/IntroductionToTheClangAST.md
    M clang/docs/LanguageExtensions.md
    M clang/docs/LibASTImporter.md
    M clang/docs/LifetimeSafety.md
    M clang/docs/SafeBuffers.md
    M clang/docs/ScalableStaticAnalysis/user-docs/SummaryExtraction.md
    M clang/docs/WarningSuppressionMappings.md
    M clang/docs/analyzer/checkers.md
    M clang/docs/analyzer/user-docs/Annotations.md
    M clang/docs/conf.py
    M clang/include/clang/AST/APValue.h
    M clang/include/clang/AST/ASTContext.h
    M clang/include/clang/AST/CharUnits.h
    M clang/include/clang/AST/NestedNameSpecifierBase.h
    M clang/include/clang/Basic/AttrDocs.td
    M clang/include/clang/CIR/Dialect/IR/CIRAttrs.td
    M clang/include/clang/CIR/Dialect/IR/CIRCUDAAttrs.td
    M clang/include/clang/CIR/Dialect/IR/CIRDialect.td
    M clang/include/clang/CIR/Dialect/IR/CIROps.td
    A clang/include/clang/ScalableStaticAnalysis/Analyses/VirtualMethodFamily/VirtualMethodFamily.h
    M clang/include/clang/ScalableStaticAnalysis/BuiltinAnchorSources.def
    M clang/lib/AST/APValue.cpp
    M clang/lib/AST/ASTContext.cpp
    M clang/lib/AST/ByteCode/Compiler.cpp
    M clang/lib/AST/ByteCode/Interp.cpp
    M clang/lib/AST/ByteCode/Interp.h
    M clang/lib/AST/ByteCode/Opcodes.td
    M clang/lib/AST/ExprConstant.cpp
    M clang/lib/AST/NestedNameSpecifier.cpp
    M clang/lib/CIR/CodeGen/CIRGenBuiltinAMDGPU.cpp
    M clang/lib/CIR/CodeGen/CIRGenCUDANV.cpp
    M clang/lib/CIR/CodeGen/CIRGenExprCXX.cpp
    M clang/lib/CIR/CodeGen/CIRGenModule.cpp
    M clang/lib/CIR/Dialect/IR/CIRDialect.cpp
    M clang/lib/CIR/Dialect/Transforms/CXXABILowering.cpp
    M clang/lib/CIR/Dialect/Transforms/LoweringPrepare.cpp
    M clang/lib/ScalableStaticAnalysis/Analyses/CMakeLists.txt
    A clang/lib/ScalableStaticAnalysis/Analyses/VirtualMethodFamily/VirtualMethodEntityExtractor.cpp
    M clang/lib/Sema/SemaOpenMP.cpp
    M clang/lib/Sema/SemaOverload.cpp
    M clang/lib/StaticAnalyzer/Checkers/WebKit/ASTUtils.cpp
    M clang/lib/StaticAnalyzer/Checkers/WebKit/PtrTypesSemantics.cpp
    M clang/lib/StaticAnalyzer/Checkers/WebKit/PtrTypesSemantics.h
    M clang/test/Analysis/Checkers/WebKit/mock-canborrow.h
    M clang/test/Analysis/Checkers/WebKit/unborrowed-call-args.cpp
    M clang/test/Analysis/Checkers/WebKit/unborrowed-local-vars-cxx23.cpp
    M clang/test/Analysis/Checkers/WebKit/unborrowed-local-vars.cpp
    M clang/test/CIR/Analysis/alias-analysis-modref.cir
    M clang/test/CIR/Analysis/alias-analysis-underlying-object.cir
    M clang/test/CIR/CodeGen/alignment.c
    M clang/test/CIR/CodeGen/atomic.c
    M clang/test/CIR/CodeGen/bitint-memory.c
    M clang/test/CIR/CodeGen/bitint-record-layout.c
    M clang/test/CIR/CodeGen/bitint-wide-be.c
    M clang/test/CIR/CodeGen/bitint-wide.c
    M clang/test/CIR/CodeGen/bitint.c
    M clang/test/CIR/CodeGen/builtin-call.cpp
    M clang/test/CIR/CodeGen/compound_literal.c
    M clang/test/CIR/CodeGen/delete-array-aligned.cpp
    M clang/test/CIR/CodeGen/delete-array-overaligned-cookie.cpp
    M clang/test/CIR/CodeGen/delete-array-throwing-dtor.cpp
    M clang/test/CIR/CodeGen/delete-array-unsized-dtor.cpp
    M clang/test/CIR/CodeGen/delete-array.cpp
    M clang/test/CIR/CodeGen/empty-union.cpp
    M clang/test/CIR/CodeGen/fixed-point-literal.c
    M clang/test/CIR/CodeGen/fp-contract.c
    M clang/test/CIR/CodeGen/global-const-alignment.cpp
    M clang/test/CIR/CodeGen/global-init-fenv.cpp
    M clang/test/CIR/CodeGen/global-section.c
    M clang/test/CIR/CodeGen/global-tls-dyn-init.cpp
    M clang/test/CIR/CodeGen/globals.cpp
    M clang/test/CIR/CodeGen/lambda.cpp
    M clang/test/CIR/CodeGen/local-const-aggregate-name-clash.cpp
    M clang/test/CIR/CodeGen/no-odr-use.cpp
    M clang/test/CIR/CodeGen/non-odr-use-non-ref.cpp
    M clang/test/CIR/CodeGen/nonzeroinit-struct.cpp
    M clang/test/CIR/CodeGen/paren-list-agg-init.cpp
    M clang/test/CIR/CodeGen/pointer-to-data-member-indirect-field.cpp
    M clang/test/CIR/CodeGen/pointer-width-32bit.cpp
    M clang/test/CIR/CodeGen/pragma-fenv_access.c
    M clang/test/CIR/CodeGen/predefined-expr.c
    M clang/test/CIR/CodeGen/source-loc.cpp
    M clang/test/CIR/CodeGen/static-local-in-ctor.cpp
    M clang/test/CIR/CodeGen/static-local-info.cpp
    M clang/test/CIR/CodeGen/tls-model.cpp
    M clang/test/CIR/CodeGen/union-agg-init.c
    M clang/test/CIR/CodeGen/vbase.cpp
    M clang/test/CIR/CodeGen/vector-strict-fp.cpp
    M clang/test/CIR/CodeGen/vtt.cpp
    M clang/test/CIR/CodeGenBuiltins/builtin-nondeterministic-value.c
    M clang/test/CIR/CodeGenCUDA/address-spaces.cu
    M clang/test/CIR/CodeGenCUDA/device-stub.cu
    M clang/test/CIR/CodeGenCUDA/kernel-call.cu
    A clang/test/CIR/CodeGenCUDA/missing-gpubinary.cu
    M clang/test/CIR/CodeGenCXX/global-refs.cpp
    M clang/test/CIR/CodeGenCXX/init-priority-attr.cpp
    M clang/test/CIR/CodeGenCXX/vtable-linkage.cpp
    M clang/test/CIR/CodeGenCXX/zero_init_bases.cpp
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn-gfx10.hip
    A clang/test/CIR/Diagnostics/mlir-error-routing.cpp
    R clang/test/CIR/Diagnostics/mlir-error-routing.cu
    M clang/test/CIR/IR/attribute-visibility.cir
    M clang/test/CIR/IR/fenv.cir
    M clang/test/CIR/IR/global.cir
    M clang/test/CIR/IR/invalid-cast.cir
    M clang/test/CIR/IR/invalid-cmp.cir
    A clang/test/CIR/IR/invalid-cuda-device-binary.cir
    M clang/test/CIR/IR/invalid-delete-array.cir
    M clang/test/CIR/IR/invalid-static-local-info.cir
    M clang/test/CIR/IR/invalid-static-local.cir
    M clang/test/CIR/IR/invalid-tls.cir
    M clang/test/CIR/IR/invalid-vtable.cir
    M clang/test/CIR/IR/static-local-info.cir
    M clang/test/CIR/IR/static-local.cir
    M clang/test/CIR/IR/string-trailing-zeros.cir
    M clang/test/CIR/IR/var-registration.cir
    M clang/test/CIR/IR/vtable-addrpt.cir
    M clang/test/CIR/IR/vtable-attr.cir
    M clang/test/CIR/IR/vtt-addrpoint.cir
    M clang/test/CIR/Lowering/call-llvm-intrinsic.cir
    M clang/test/CIR/Lowering/fenv.cir
    M clang/test/CIR/Lowering/vtt-addrpoint.cir
    M clang/test/CIR/Transforms/vector-cmp-fold.cir
    R clang/test/CodeGen/AArch64/sve-intrinsics/acle_sve_addv.c
    A clang/test/CodeGen/AArch64/sve/addv.c
    A clang/test/CodeGen/RISCV/lto-module-asm-abi.c
    A clang/test/OpenMP/collapse_iv_width_codegen.cpp
    A clang/test/SemaCXX/new-nothrow-by-value.cpp
    M clang/tools/clang-ssaf-src-edit-merge/SrcEditMerge.cpp
    M clang/unittests/CIR/FenvOpTest.cpp
    A clang/unittests/ScalableStaticAnalysis/Analyses/VirtualMethodFamily/VirtualMethodFamilyExtractorTest.cpp
    A clang/unittests/ScalableStaticAnalysis/Analyses/VirtualMethodFamily/VirtualMethodFamilyTestSupport.h
    M clang/unittests/ScalableStaticAnalysis/CMakeLists.txt
    A clang/unittests/ScalableStaticAnalysis/ParsedAST.h
    A cross-project-tests/.clang-format
    A cross-project-tests/riscv/lit.local.cfg
    A cross-project-tests/riscv/lto-inline-asm-abi.c
    M flang/docs/OpenMPSupport.md
    M flang/include/flang/Optimizer/Transforms/Passes.td
    M flang/lib/Lower/OpenMP/OpenMP.cpp
    M flang/lib/Optimizer/Transforms/CMakeLists.txt
    M flang/lib/Optimizer/Transforms/LoopInvariantCodeMotion.cpp
    A flang/test/Integration/OpenMP/allocate-clause-equivalence.f90
    A flang/test/Integration/OpenMP/scope-allocate-clause.f90
    M flang/test/Lower/OpenMP/Todo/allocate-clause-unsupported.f90
    A flang/test/Lower/OpenMP/Todo/scope-allocate-clause-unsupported.f90
    M flang/test/Lower/OpenMP/scope.f90
    M flang/test/Lower/OpenMP/target-scope.f90
    A flang/test/Transforms/licm-acc-captured-ref.fir
    A flang/test/Transforms/licm-acc-compute-only.fir
    A flang/test/Transforms/licm-scope.fir
    M libc/src/__support/OSUtil/linux/syscall_wrappers/close.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/dup.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/dup2.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/dup3.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/fcntl.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/fsync.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/ftruncate.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/lseek.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/memfd_create.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/read.h
    M libc/src/__support/OSUtil/linux/syscall_wrappers/write.h
    A libcxx/docs/ABIGuarantees.md
    R libcxx/docs/ABIGuarantees.rst
    A libcxx/docs/AddingNewCIJobs.md
    R libcxx/docs/AddingNewCIJobs.rst
    A libcxx/docs/CodingGuidelines.md
    R libcxx/docs/CodingGuidelines.rst
    A libcxx/docs/Contributing.md
    R libcxx/docs/Contributing.rst
    A libcxx/docs/Contributing/NewStandardProcedure.md
    R libcxx/docs/Contributing/NewStandardProcedure.rst
    A libcxx/docs/Contributing/PostMeetingProcedure.md
    R libcxx/docs/Contributing/PostMeetingProcedure.rst
    A libcxx/docs/Contributing/ReleaseProcedure.md
    R libcxx/docs/Contributing/ReleaseProcedure.rst
    A libcxx/docs/DesignDocs/ABIVersioning.md
    R libcxx/docs/DesignDocs/ABIVersioning.rst
    A libcxx/docs/DesignDocs/AtomicDesign.md
    R libcxx/docs/DesignDocs/AtomicDesign.rst
    A libcxx/docs/DesignDocs/CapturingConfigInfo.md
    R libcxx/docs/DesignDocs/CapturingConfigInfo.rst
    A libcxx/docs/DesignDocs/ExperimentalFeatures.md
    R libcxx/docs/DesignDocs/ExperimentalFeatures.rst
    A libcxx/docs/DesignDocs/ExtendedCXX03Support.md
    R libcxx/docs/DesignDocs/ExtendedCXX03Support.rst
    A libcxx/docs/DesignDocs/FeatureTestMacros.md
    R libcxx/docs/DesignDocs/FeatureTestMacros.rst
    A libcxx/docs/DesignDocs/FileTimeType.md
    R libcxx/docs/DesignDocs/FileTimeType.rst
    A libcxx/docs/DesignDocs/HeaderRemovalPolicy.md
    R libcxx/docs/DesignDocs/HeaderRemovalPolicy.rst
    M libcxx/docs/conf.py
    M libcxx/include/__chrono/duration.h
    M libcxx/include/__configuration/abi.h
    M libcxx/include/__format/buffer.h
    M libcxx/include/__ostream/print.h
    M libcxx/include/complex
    M libcxx/include/valarray
    A libcxx/test/benchmarks/algorithms/nonmodifying/pstl.find.bench.cpp
    A libcxx/test/benchmarks/algorithms/sorting/pstl.sort.bench.cpp
    A libcxx/test/benchmarks/numeric/pstl.transform_reduce.bench.cpp
    M libcxx/test/configs/ibm-libc++-shared.cfg.in
    A libcxx/test/std/numerics/complex.number/complex/complex_requires_cv_unqualified_object.verify.cpp
    A libcxx/test/std/numerics/numarray/template.valarray/valarray_requires_cv_unqualified_object.verify.cpp
    M libcxx/test/std/time/months.pass.cpp
    M libcxx/test/std/time/years.pass.cpp
    A libcxx/test/std/utilities/format/format.functions/bug_154670.pass.cpp
    M libcxx/utils/ci/docker/linux-builder.dockerfile
    M lld/test/ELF/lto/riscv-target-abi.ll
    M lldb/test/API/api/multiple-debuggers/multi-process-driver.cpp
    M lldb/test/API/functionalities/scripted_frame_provider/thread_filter/TestFrameProviderThreadFilter.py
    M lldb/unittests/ObjectContainer/ObjectContainerClangOffloadBundleTest.cpp
    M llvm/cmake/modules/GetLibraryName.cmake
    M llvm/docs/Lexicon.md
    M llvm/docs/ORCv2.md
    M llvm/docs/SphinxQuickstartTemplate.md
    M llvm/include/llvm-c/DebugInfo.h
    M llvm/include/llvm/ADT/DenseMap.h
    M llvm/include/llvm/ADT/DenseMapInfo.h
    M llvm/include/llvm/Analysis/LoopAccessAnalysis.h
    M llvm/include/llvm/Analysis/ScalarEvolution.h
    M llvm/include/llvm/Analysis/ScalarEvolutionExpressions.h
    M llvm/include/llvm/Analysis/TargetTransformInfo.h
    M llvm/include/llvm/Analysis/TargetTransformInfoImpl.h
    M llvm/include/llvm/AsmParser/LLParser.h
    M llvm/include/llvm/BinaryFormat/Dwarf.def
    M llvm/include/llvm/BinaryFormat/Dwarf.h
    M llvm/include/llvm/BinaryFormat/ELF.h
    M llvm/include/llvm/CGData/CodeGenData.h
    M llvm/include/llvm/CGData/CodeGenDataReader.h
    M llvm/include/llvm/CodeGen/AsmPrinter.h
    M llvm/include/llvm/CodeGen/BasicTTIImpl.h
    M llvm/include/llvm/CodeGen/SDPatternMatch.h
    M llvm/include/llvm/CodeGen/TargetLowering.h
    M llvm/include/llvm/CodeGen/TargetLoweringObjectFileImpl.h
    M llvm/include/llvm/ExecutionEngine/Orc/Core.h
    M llvm/include/llvm/ExecutionEngine/Orc/Debugging/PerfSupportPlugin.h
    M llvm/include/llvm/ExecutionEngine/Orc/Debugging/VTuneSupportPlugin.h
    M llvm/include/llvm/ExecutionEngine/Orc/ExecutorProcessControl.h
    M llvm/include/llvm/Object/ELFTypes.h
    M llvm/include/llvm/Target/TargetMachine.h
    M llvm/include/llvm/Transforms/Scalar/GVN.h
    M llvm/include/llvm/Transforms/Utils/LoopUtils.h
    M llvm/lib/Analysis/BasicAliasAnalysis.cpp
    M llvm/lib/Analysis/LoopAccessAnalysis.cpp
    M llvm/lib/Analysis/ScalarEvolution.cpp
    M llvm/lib/Analysis/TargetTransformInfo.cpp
    M llvm/lib/AsmParser/LLParser.cpp
    M llvm/lib/BinaryFormat/Dwarf.cpp
    M llvm/lib/CGData/CodeGenData.cpp
    M llvm/lib/CGData/CodeGenDataReader.cpp
    M llvm/lib/CodeGen/AsmPrinter/AsmPrinter.cpp
    M llvm/lib/CodeGen/CodeGenPrepare.cpp
    M llvm/lib/CodeGen/GlobalISel/GISelValueTracking.cpp
    M llvm/lib/CodeGen/GlobalISel/LegalizerHelper.cpp
    M llvm/lib/CodeGen/LiveDebugValues/InstrRefBasedImpl.cpp
    M llvm/lib/CodeGen/MachineBasicBlock.cpp
    M llvm/lib/CodeGen/SelectionDAG/LegalizeTypes.h
    M llvm/lib/CodeGen/SelectionDAG/LegalizeVectorTypes.cpp
    M llvm/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
    M llvm/lib/CodeGen/SelectionDAG/SelectionDAGBuilder.cpp
    M llvm/lib/CodeGen/TargetLoweringBase.cpp
    M llvm/lib/CodeGen/TargetLoweringObjectFileImpl.cpp
    M llvm/lib/ExecutionEngine/Orc/Debugging/PerfSupportPlugin.cpp
    M llvm/lib/ExecutionEngine/Orc/Debugging/VTuneSupportPlugin.cpp
    M llvm/lib/Frontend/OpenMP/OMPDescriptors.inc
    M llvm/lib/IR/Verifier.cpp
    M llvm/lib/LTO/LTO.cpp
    M llvm/lib/Linker/IRMover.cpp
    M llvm/lib/MC/ELFObjectWriter.cpp
    M llvm/lib/ObjectYAML/DWARFEmitter.cpp
    M llvm/lib/Support/CMakeLists.txt
    A llvm/lib/Support/DenseMap.cpp
    M llvm/lib/Target/AArch64/AArch64CodeLayoutOpt.cpp
    M llvm/lib/Target/AArch64/AArch64ISelLowering.cpp
    M llvm/lib/Target/AArch64/AArch64PerfectShuffle.h
    M llvm/lib/Target/AArch64/AArch64TargetMachine.h
    M llvm/lib/Target/AArch64/AArch64TargetTransformInfo.cpp
    M llvm/lib/Target/AArch64/AArch64TargetTransformInfo.h
    M llvm/lib/Target/AMDGPU/AMDGPU.td
    M llvm/lib/Target/AMDGPU/AMDGPUInstCombineIntrinsic.cpp
    M llvm/lib/Target/AMDGPU/AMDGPULegalizerInfo.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUTargetMachine.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUTargetMachine.h
    M llvm/lib/Target/AMDGPU/GCNHazardRecognizer.cpp
    M llvm/lib/Target/AMDGPU/GCNHazardRecognizer.h
    M llvm/lib/Target/AMDGPU/SIISelLowering.cpp
    M llvm/lib/Target/AMDGPU/SIISelLowering.h
    M llvm/lib/Target/AMDGPU/SIInstrInfo.td
    M llvm/lib/Target/AMDGPU/VOP3Instructions.td
    M llvm/lib/Target/ARM/ARMInstructionSelector.cpp
    M llvm/lib/Target/ARM/ARMTargetMachine.cpp
    M llvm/lib/Target/ARM/ARMTargetMachine.h
    M llvm/lib/Target/ARM/ARMTargetObjectFile.cpp
    M llvm/lib/Target/ARM/ARMTargetObjectFile.h
    M llvm/lib/Target/AVR/AVRTargetMachine.h
    M llvm/lib/Target/Hexagon/HexagonConstPropagation.cpp
    M llvm/lib/Target/Hexagon/HexagonTargetMachine.h
    M llvm/lib/Target/LoongArch/LoongArchTargetMachine.h
    M llvm/lib/Target/M68k/M68kExpandPseudo.cpp
    M llvm/lib/Target/M68k/M68kInstrArithmetic.td
    M llvm/lib/Target/M68k/M68kInstrData.td
    M llvm/lib/Target/M68k/M68kInstrInfo.cpp
    M llvm/lib/Target/M68k/M68kInstrInfo.h
    M llvm/lib/Target/M68k/M68kTargetObjectFile.cpp
    M llvm/lib/Target/M68k/M68kTargetObjectFile.h
    M llvm/lib/Target/MSP430/MSP430AsmPrinter.cpp
    M llvm/lib/Target/Mips/MipsAsmPrinter.cpp
    M llvm/lib/Target/Mips/MipsSubtarget.cpp
    M llvm/lib/Target/Mips/MipsSubtarget.h
    M llvm/lib/Target/Mips/MipsTargetMachine.cpp
    M llvm/lib/Target/Mips/MipsTargetMachine.h
    M llvm/lib/Target/NVPTX/NVPTXAsmPrinter.cpp
    M llvm/lib/Target/PowerPC/PPC.h
    M llvm/lib/Target/PowerPC/PPCTargetMachine.h
    M llvm/lib/Target/RISCV/MCTargetDesc/RISCVELFStreamer.cpp
    M llvm/lib/Target/RISCV/MCTargetDesc/RISCVELFStreamer.h
    M llvm/lib/Target/RISCV/MCTargetDesc/RISCVTargetStreamer.cpp
    M llvm/lib/Target/RISCV/MCTargetDesc/RISCVTargetStreamer.h
    M llvm/lib/Target/RISCV/RISCVAsmPrinter.cpp
    M llvm/lib/Target/RISCV/RISCVTargetMachine.cpp
    M llvm/lib/Target/RISCV/RISCVTargetMachine.h
    M llvm/lib/Target/SPIRV/SPIRVSubtarget.cpp
    M llvm/lib/Target/Sparc/SparcISelLowering.cpp
    M llvm/lib/Target/SystemZ/SystemZFrameLowering.cpp
    M llvm/lib/Target/SystemZ/SystemZISelLowering.cpp
    M llvm/lib/Target/SystemZ/SystemZXPLINKAsmPrinter.cpp
    M llvm/lib/Target/VE/VEISelLowering.cpp
    M llvm/lib/Target/X86/GISel/X86LegalizerInfo.cpp
    M llvm/lib/Target/X86/X86ISelDAGToDAG.cpp
    M llvm/lib/Target/X86/X86ISelLowering.cpp
    M llvm/lib/Target/X86/X86RegisterInfo.td
    M llvm/lib/Target/X86/X86TargetMachine.cpp
    M llvm/lib/Target/X86/X86TargetMachine.h
    M llvm/lib/Transforms/IPO/MergeFunctions.cpp
    M llvm/lib/Transforms/Instrumentation/AddressSanitizer.cpp
    M llvm/lib/Transforms/Scalar/ConstraintElimination.cpp
    M llvm/lib/Transforms/Scalar/GVN.cpp
    M llvm/lib/Transforms/Utils/BuildLibCalls.cpp
    M llvm/lib/Transforms/Utils/CodeExtractor.cpp
    M llvm/lib/Transforms/Utils/LoopUnroll.cpp
    M llvm/lib/Transforms/Utils/LoopUtils.cpp
    M llvm/lib/Transforms/Utils/SimplifyCFG.cpp
    M llvm/lib/Transforms/Vectorize/LoopVectorize.cpp
    M llvm/lib/Transforms/Vectorize/SLPVectorizer.cpp
    M llvm/lib/Transforms/Vectorize/SLPVectorizer/SLPUtils.cpp
    M llvm/lib/Transforms/Vectorize/VPlan.h
    M llvm/lib/Transforms/Vectorize/VPlanConstruction.cpp
    M llvm/lib/Transforms/Vectorize/VPlanRecipes.cpp
    M llvm/lib/Transforms/Vectorize/VPlanTransforms.cpp
    M llvm/lib/Transforms/Vectorize/VPlanTransforms.h
    M llvm/lib/Transforms/Vectorize/VPlanUtils.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUtils.h
    M llvm/test/Analysis/CostModel/AArch64/speculative-load.ll
    M llvm/test/Analysis/CostModel/X86/arith-fp.ll
    M llvm/test/Analysis/CostModel/X86/speculative-load.ll
    A llvm/test/Assembler/invalid-diexpression-arg-negative.ll
    M llvm/test/Bitcode/upgrade-tbaa.ll
    A llvm/test/Bitcode/upgrade-tbaa.ll.bc
    A llvm/test/CodeGen/AArch64/GlobalISel/knownbits-freeze.mir
    M llvm/test/CodeGen/AArch64/GlobalISel/knownfpclass-ops.mir
    M llvm/test/CodeGen/AArch64/binopshuffles.ll
    M llvm/test/CodeGen/AArch64/fp-intrinsics-vector.ll
    M llvm/test/CodeGen/AArch64/lowmaskedlanes.ll
    M llvm/test/CodeGen/AArch64/neon-truncstore.ll
    M llvm/test/CodeGen/AArch64/store.ll
    M llvm/test/CodeGen/AArch64/sve-extract-vector-to-predicate-store.ll
    M llvm/test/CodeGen/AArch64/vec3-loads-ext-trunc-stores.ll
    M llvm/test/CodeGen/AMDGPU/mai-hazards-gfx90a.mir
    M llvm/test/CodeGen/AMDGPU/mai-hazards-gfx942.mir
    A llvm/test/CodeGen/AMDGPU/phi-elimination-split-critical-edge-subranges.mir
    A llvm/test/CodeGen/AMDGPU/rewrite-vgpr-mfma-to-agpr-spill-multi-store-codegen.ll
    M llvm/test/CodeGen/AMDGPU/rewrite-vgpr-mfma-to-agpr-spill-multi-store.ll
    M llvm/test/CodeGen/ARM/module-target-abi.ll
    M llvm/test/CodeGen/M68k/Arith/divide-by-constant.ll
    M llvm/test/CodeGen/M68k/Arith/smul-with-overflow.ll
    M llvm/test/CodeGen/M68k/Arith/umul-with-overflow.ll
    M llvm/test/CodeGen/M68k/Bits/btst.ll
    M llvm/test/CodeGen/M68k/Control/cmp.ll
    M llvm/test/CodeGen/M68k/Control/non-cmov-switch.ll
    M llvm/test/CodeGen/M68k/Control/setcc.ll
    M llvm/test/CodeGen/M68k/Data/load-extend.ll
    M llvm/test/CodeGen/M68k/Data/sext-i1.ll
    M llvm/test/CodeGen/M68k/register-spills.ll
    A llvm/test/CodeGen/Mips/target-abi-module-flag.ll
    M llvm/test/CodeGen/RISCV/module-asm-features.ll
    M llvm/test/CodeGen/RISCV/riscv-func-target-feature.ll
    A llvm/test/CodeGen/X86/bzhi-standalone-mask.ll
    M llvm/test/CodeGen/X86/cmp-shiftX-maskX.ll
    A llvm/test/CodeGen/X86/cmp-shrink-unsigned.ll
    A llvm/test/DebugInfo/AArch64/dbg-value-arg-index-out-of-range.ll
    A llvm/test/DebugInfo/Generic/compileunit-source-language-name-roc.ll
    M llvm/test/LTO/RISCV/module-asm.ll
    M llvm/test/MC/AMDGPU/gfx13_asm_vop3-fake16.s
    M llvm/test/MC/AMDGPU/gfx13_asm_vop3.s
    A llvm/test/MC/AMDGPU/gfx13_asm_vop3_from_vop1_err-fake16.s
    A llvm/test/MC/AMDGPU/gfx13_asm_vop3_from_vop1_err.s
    M llvm/test/MC/RISCV/mapping-across-sections.s
    M llvm/test/Transforms/ConstraintElimination/analysis-invalidation.ll
    A llvm/test/Transforms/HotColdSplit/split-out-dbg-val-arglist.ll
    M llvm/test/Transforms/InferFunctionAttrs/annotate.ll
    M llvm/test/Transforms/InstCombine/AMDGPU/llvm.amdgcn.dot.ll
    M llvm/test/Transforms/LoopVectorize/AArch64/conditional-scalar-assignment-fold-tail.ll
    M llvm/test/Transforms/LoopVectorize/AArch64/conditional-scalar-assignment.ll
    M llvm/test/Transforms/LoopVectorize/AArch64/epilog-vectorization-widen-inductions.ll
    A llvm/test/Transforms/LoopVectorize/AArch64/sve-induction-wrapflags.ll
    M llvm/test/Transforms/LoopVectorize/AArch64/sve-low-trip-count.ll
    M llvm/test/Transforms/LoopVectorize/RISCV/conditional-scalar-assignment-fold-tail.ll
    M llvm/test/Transforms/LoopVectorize/RISCV/conditional-scalar-assignment.ll
    M llvm/test/Transforms/LoopVectorize/RISCV/countable-early-exit-no-epilogue.ll
    M llvm/test/Transforms/LoopVectorize/VPlan/execution-frequencies-match-bfi.ll
    M llvm/test/Transforms/LoopVectorize/X86/conditional-scalar-assignment.ll
    M llvm/test/Transforms/LoopVectorize/X86/pr36524.ll
    M llvm/test/Transforms/LoopVectorize/X86/predicated-instruction-cost.ll
    M llvm/test/Transforms/LoopVectorize/find-last-ptr-induction.ll
    M llvm/test/Transforms/LoopVectorize/induction-wrapflags.ll
    M llvm/test/Transforms/LoopVectorize/induction.ll
    M llvm/test/Transforms/LoopVectorize/iv-select-cmp-non-const-iv-start.ll
    M llvm/test/Transforms/LoopVectorize/iv-select-cmp-trunc.ll
    M llvm/test/Transforms/LoopVectorize/iv-select-cmp.ll
    M llvm/test/Transforms/LoopVectorize/pr30654-phiscev-sext-trunc.ll
    M llvm/test/Transforms/LoopVectorize/pr35773.ll
    M llvm/test/Transforms/LoopVectorize/predicated-inductions.ll
    M llvm/test/Transforms/LoopVectorize/replicate-region-branch-weights.ll
    M llvm/test/Transforms/LoopVectorize/single-value-blend-phis.ll
    A llvm/test/Transforms/MergeFunc/redirect-call-debug-loc.ll
    A llvm/test/Transforms/SLPVectorizer/AMDGPU/cross-block-fmul-fadd.ll
    A llvm/test/Transforms/SLPVectorizer/X86/extracted-subfields-shifted-trunc.ll
    M llvm/test/Transforms/SLPVectorizer/X86/extracted-subfields.ll
    A llvm/test/Transforms/SLPVectorizer/X86/narrowed-reduction-gathered-leftover-leaf.ll
    M llvm/test/Transforms/SLPVectorizer/X86/runtime-alias-checks.ll
    A llvm/test/Transforms/SLPVectorizer/X86/strength-reducible-address.ll
    A llvm/test/Transforms/SLPVectorizer/X86/trimmed-node-matching-gather-emitted-first.ll
    A llvm/test/Transforms/SimplifyCFG/AArch64/speculate-vector-phi-select-cost.ll
    A llvm/test/Transforms/SimplifyCFG/ARM/speculate-vector-phi-select-cost.ll
    A llvm/test/Transforms/SimplifyCFG/RISCV/speculate-mask-phi-select-cost.ll
    A llvm/test/Transforms/SimplifyCFG/X86/speculate-mask-phi-select-cost.ll
    M llvm/test/Transforms/SimplifyCFG/hoist-common-skip.ll
    A llvm/test/Verifier/dbg-record-expression-arg-out-of-range.ll
    M llvm/tools/dsymutil/DwarfLinkerForBinary.h
    M llvm/tools/llvm-cgdata/llvm-cgdata.cpp
    M llvm/tools/llvm-cov/CodeCoverage.cpp
    M llvm/tools/llvm-jitlink/llvm-jitlink.cpp
    M llvm/tools/llvm-objdump/COFFDump.h
    M llvm/tools/llvm-objdump/ELFDump.h
    M llvm/tools/llvm-objdump/OffloadDump.cpp
    M llvm/tools/llvm-objdump/WasmDump.h
    M llvm/tools/llvm-profgen/PerfReader.h
    M llvm/unittests/ADT/DenseMapTest.cpp
    M llvm/unittests/CodeGen/GlobalISel/LegalizerHelperTest.cpp
    M llvm/unittests/ExecutionEngine/Orc/ExecutionSessionWrapperFunctionCallsTest.cpp
    M llvm/unittests/Support/LLVMToolSession/LLVMToolSessionTest.cpp
    M llvm/utils/LLVMVisualizers/llvm.natvis
    M llvm/utils/gdb-scripts/prettyprinters.py
    M llvm/utils/gn/secondary/clang/lib/ScalableStaticAnalysis/Analyses/BUILD.gn
    M llvm/utils/gn/secondary/clang/unittests/ScalableStaticAnalysis/BUILD.gn
    M llvm/utils/gn/secondary/libcxx/include/BUILD.gn
    M llvm/utils/gn/secondary/llvm/lib/Support/BUILD.gn
    M llvm/utils/lldbDataFormatters.py
    M mlir/examples/toy/Ch4/include/toy/Ops.td
    M mlir/examples/toy/Ch5/include/toy/Ops.td
    M mlir/examples/toy/Ch6/include/toy/Ops.td
    M mlir/examples/toy/Ch7/include/toy/Ops.td
    M mlir/include/mlir/Dialect/LLVMIR/LLVMIntrinsicOps.td
    M mlir/include/mlir/Dialect/LLVMIR/NVVMOps.td
    M mlir/include/mlir/Dialect/Tosa/IR/TosaOps.td
    M mlir/include/mlir/Dialect/Utils/StaticValueUtils.h
    M mlir/lib/Dialect/GPU/CMakeLists.txt
    M mlir/lib/Dialect/GPU/Transforms/DecomposeMemRefs.cpp
    M mlir/lib/Dialect/MemRef/IR/MemRefOps.cpp
    M mlir/lib/Dialect/MemRef/Transforms/ExpandStridedMetadata.cpp
    M mlir/lib/Dialect/OpenMP/IR/OpenMPDialect.cpp
    M mlir/lib/Dialect/Utils/StaticValueUtils.cpp
    M mlir/lib/IR/BuiltinTypes.cpp
    M mlir/lib/Target/LLVMIR/Dialect/LLVMIR/LLVMToLLVMIRTranslation.cpp
    M mlir/lib/Target/LLVMIR/Dialect/OpenMP/OpenMPToLLVMIRTranslation.cpp
    M mlir/test/Analysis/DataFlow/test-last-modified-callgraph.mlir
    M mlir/test/Analysis/DataFlow/test-last-modified.mlir
    M mlir/test/Analysis/DataFlow/test-next-access.mlir
    M mlir/test/Analysis/DataFlow/test-strided-metadata-range-analysis.mlir
    M mlir/test/Conversion/MemRefToSPIRV/memref-to-spirv.mlir
    M mlir/test/Conversion/TosaToSPIRVTosa/graph-constant-mark.mlir
    M mlir/test/Dialect/Affine/affine-loop-normalize.mlir
    M mlir/test/Dialect/Affine/int-range-interface.mlir
    M mlir/test/Dialect/Affine/simplify-min-max-ops.mlir
    M mlir/test/Dialect/Affine/simplify-with-bounds.mlir
    M mlir/test/Dialect/Affine/transform-op-simplify-min-max-ops.mlir
    M mlir/test/Dialect/Arith/int-range-analysis-convergence.mlir
    M mlir/test/Dialect/Arith/int-range-interface.mlir
    M mlir/test/Dialect/Arith/int-range-loop-iter-args.mlir
    M mlir/test/Dialect/Arith/int-range-narrowing.mlir
    M mlir/test/Dialect/Arith/int-range-opts-bug-119045.mlir
    M mlir/test/Dialect/Arith/int-range-opts.mlir
    M mlir/test/Dialect/GPU/decompose-memrefs.mlir
    M mlir/test/Dialect/GPU/int-range-interface-cluster.mlir
    M mlir/test/Dialect/GPU/int-range-interface.mlir
    M mlir/test/Dialect/LLVMIR/nvvm_check_target_sm.mlir
    M mlir/test/Dialect/LLVMIR/roundtrip.mlir
    M mlir/test/Dialect/MLProgram/pipeline-globals.mlir
    M mlir/test/Dialect/MemRef/canonicalize.mlir
    M mlir/test/Dialect/MemRef/elide-reinterpret-cast-load.mlir
    M mlir/test/Dialect/MemRef/expand-strided-metadata.mlir
    M mlir/test/Dialect/MemRef/int-range-inference.mlir
    M mlir/test/Dialect/MemRef/ops.mlir
    M mlir/test/Dialect/OpenACC/acc-implicit-routine.mlir
    M mlir/test/Dialect/OpenMP/invalid.mlir
    M mlir/test/Dialect/OpenMP/ops.mlir
    M mlir/test/Dialect/Tensor/int-range-inference.mlir
    M mlir/test/Dialect/Tosa/canonicalize.mlir
    M mlir/test/Dialect/Tosa/constant_folding.mlir
    M mlir/test/Dialect/Tosa/ops.mlir
    M mlir/test/Dialect/Tosa/tosa-arith-const-to-tosa-const.mlir
    M mlir/test/Dialect/Tosa/tosa-convert-integer-type-to-signless.mlir
    M mlir/test/Dialect/Tosa/tosa-decompose-depthwise.mlir
    M mlir/test/Dialect/Tosa/tosa-decompose-transpose-conv.mlir
    M mlir/test/Dialect/Tosa/tosa-gather-scatter-hardening.mlir
    M mlir/test/Dialect/Tosa/tosa-infer-shapes.mlir
    M mlir/test/Dialect/Tosa/tosa-layerwise-constant-fold-dense-resource.mlir
    M mlir/test/Dialect/Tosa/tosa-layerwise-constant-fold.mlir
    M mlir/test/Dialect/Tosa/tosa-narrow-f32-to-f16-aggressive.mlir
    M mlir/test/Dialect/Tosa/tosa-narrow-f32-to-f16.mlir
    M mlir/test/Dialect/Tosa/tosa-narrow-f64-to-f32-aggressive.mlir
    M mlir/test/Dialect/Tosa/tosa-narrow-f64-to-f32.mlir
    M mlir/test/Dialect/Tosa/tosa-narrow-i64-to-i32-aggressive.mlir
    M mlir/test/Dialect/Tosa/tosa-narrow-i64-to-i32.mlir
    M mlir/test/Dialect/Tosa/tosa-reduce-transposes.mlir
    M mlir/test/Dialect/Vector/int-range-interface.mlir
    M mlir/test/IR/attribute.mlir
    M mlir/test/Interfaces/InferIntRangeInterface/infer-int-range-test-ops-invalid.mlir
    M mlir/test/Interfaces/InferIntRangeInterface/infer-int-range-test-ops.mlir
    M mlir/test/Target/LLVMIR/Import/intrinsic.ll
    M mlir/test/Target/LLVMIR/llvmir-intrinsics.mlir
    M mlir/test/Target/LLVMIR/llvmir.mlir
    M mlir/test/Target/LLVMIR/openmp-allocate-clause.mlir
    A mlir/test/Target/LLVMIR/openmp-scope-allocate-clause.mlir
    M mlir/test/Target/LLVMIR/openmp-todo.mlir
    M mlir/test/Transforms/loop-invariant-code-motion.mlir
    M mlir/test/Transforms/make-composed-folded-affine-apply.mlir
    M mlir/test/lib/Dialect/Test/TestDialect.td
    M mlir/test/lib/Dialect/Test/TestOps.td
    M mlir/test/lib/Dialect/Test/TestOpsSyntax.td
    M mlir/test/mlir-tblgen/constant-str-attr-invalid.mlir
    M mlir/test/mlir-tblgen/op-format-invalid.td
    M mlir/test/mlir-tblgen/op-format.mlir
    M mlir/test/mlir-tblgen/op-format.td
    M mlir/test/mlir-tblgen/pattern.mlir
    M mlir/test/python/dialects/python_test.py
    M mlir/test/python/python_test_ops.td
    M orc-rt/cmake/OrcRTTesting.cmake
    M orc-rt/include/CMakeLists.txt
    M orc-rt/include/orc-rt-c/config.h.in
    A orc-rt/include/orc-rt-c/support/LogLevel.h
    M orc-rt/include/orc-rt-c/support/Logging.h
    M orc-rt/include/orc-rt/bedrock/ConnectorRegistry.h
    M orc-rt/include/orc-rt/bedrock/Session.h
    M orc-rt/lib/bedrock/ConnectorRegistry.cpp
    M orc-rt/lib/bedrock/sys/posix/SocketConnector.cpp
    A orc-rt/lib/bedrock/sys/windows/SocketConnector.cpp
    M orc-rt/test/regression/README.md
    M orc-rt/test/regression/jit-free-foundations/check-rt-process-info.test
    M orc-rt/test/regression/jit-free-foundations/lit.local.cfg
    A orc-rt/test/regression/languages/c/addressing/cross-object/global-array-element-pointer-in-data.test
    A orc-rt/test/regression/languages/c/addressing/cross-object/global-data-load.test
    A orc-rt/test/regression/languages/c/addressing/cross-object/hidden-data-load.test
    A orc-rt/test/regression/languages/c/addressing/same-object/global-data-pointer-in-data.c
    A orc-rt/test/regression/languages/c/addressing/same-object/global-data-store.c
    A orc-rt/test/regression/languages/c/addressing/same-object/static-array-element-load.c
    A orc-rt/test/regression/languages/c/addressing/same-object/static-data-load.c
    M orc-rt/test/regression/languages/c/lit.local.cfg
    M orc-rt/test/regression/languages/c/return-zero.c
    M orc-rt/test/regression/lit.cfg.py
    M orc-rt/test/regression/object-formats/lit.local.cfg
    M orc-rt/test/regression/object-formats/mach-o/arm64/return-zero.s
    M orc-rt/test/tools/orc-rt-process-info-check.cpp
    M orc-rt/test/unit/bedrock/sys/posix/SocketConnectorTest.cpp
    M orc-rt/tools/ogre/CMakeLists.txt
    M orc-rt/tools/ogre/ogre.cpp
    M polly/test/CodeGen/OpenMP/single_loop_with_loop_invariant_baseptr.ll
    M utils/docs/llvm_sphinx/ext/absolute_links.py
    M utils/docs/llvm_sphinx/ext/absolute_links_test/markdown.md

  Log Message:
  -----------
  Rebase

Created using spr 1.3.7


Compare: https://github.com/llvm/llvm-project/compare/1916c2c7fec0...bafd66d33189

To unsubscribe from these emails, change your notification settings at https://github.com/llvm/llvm-project/settings/notifications


More information about the All-commits mailing list